/* Driver template for the LEMON parser generator.
** The author disclaims copyright to this source code.
*/
/* First off, code is included that follows the "include" declaration
** in the input grammar file. */
#include <stdio.h>
#line 53 "parse.y"

#include "sqliteInt.h"

/*
** An instance of this structure holds information about the
** LIMIT clause of a SELECT statement.
*/
struct LimitVal {
  Expr *pLimit;    /* The LIMIT expression.  NULL if there is no limit */
  Expr *pOffset;   /* The OFFSET expression.  NULL if there is none */
};

/*
** An instance of this structure is used to store the LIKE,
** GLOB, NOT LIKE, and NOT GLOB operators.
*/
struct LikeOp {
  Token eOperator;  /* "like" or "glob" or "regexp" */
  int not;         /* True if the NOT keyword is present */
};

/*
** An instance of the following structure describes the event of a
** TRIGGER.  "a" is the event type, one of TK_UPDATE, TK_INSERT,
** TK_DELETE, or TK_INSTEAD.  If the event is of the form
**
**      UPDATE ON (a,b,c)
**
** Then the "b" IdList records the list "a,b,c".
*/
struct TrigEvent { int a; IdList * b; };

/*
** An instance of this structure holds the ATTACH key and the key type.
*/
struct AttachKey { int type;  Token key; };

#line 46 "parse.c"
/* Next is all token values, in a form suitable for use by makeheaders.
** This section will be null unless lemon is run with the -m switch.
*/
/* 
** These constants (all generated automatically by the parser generator)
** specify the various kinds of tokens (terminals) that the parser
** understands. 
**
** Each symbol here is a terminal symbol in the grammar.
*/
/* Make sure the INTERFACE macro is defined.
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/* The next thing included is series of defines which control
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 terminals
**                       and nonterminals.  "int" is used otherwise.
**    YYNOCODE           is a number of type YYCODETYPE which corresponds
**                       to no legal terminal or nonterminal number.  This
**                       number is used to fill in empty slots of the hash 
**                       table.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       have fall-back values which should be used if the
**                       original value of the token will not parse.
**    YYACTIONTYPE       is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 rules and
**                       states combined.  "int" is used otherwise.
**    sqlite3ParserTOKENTYPE     is the data type used for minor tokens given 
**                       directly to the parser from the tokenizer.
**    YYMINORTYPE        is the data type used for all minor tokens.
**                       This is typically a union of many types, one of
**                       which is sqlite3ParserTOKENTYPE.  The entry in the union
**                       for base tokens is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    sqlite3ParserARG_SDECL     A static variable declaration for the %extra_argument
**    sqlite3ParserARG_PDECL     A parameter declaration for the %extra_argument
**    sqlite3ParserARG_STORE     Code to store %extra_argument into yypParser
**    sqlite3ParserARG_FETCH     Code to extract %extra_argument from yypParser
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
*/
#define YYCODETYPE unsigned short int
#define YYNOCODE 252
#define YYACTIONTYPE unsigned short int
#define YYWILDCARD 65
#define sqlite3ParserTOKENTYPE Token
typedef union {
  int yyinit;
  sqlite3ParserTOKENTYPE yy0;
  Expr* yy72;
  TriggerStep* yy145;
  ExprList* yy148;
  SrcList* yy185;
  int yy194;
  Select* yy243;
  IdList* yy254;
  struct TrigEvent yy332;
  struct LimitVal yy354;
  struct LikeOp yy392;
  struct {int value; int mask;} yy497;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#define sqlite3ParserARG_SDECL Parse *pParse;
#define sqlite3ParserARG_PDECL ,Parse *pParse
#define sqlite3ParserARG_FETCH Parse *pParse = yypParser->pParse
#define sqlite3ParserARG_STORE yypParser->pParse = pParse
#define YYNSTATE 616
#define YYNRULE 323
#define YYFALLBACK 1
#define YY_NO_ACTION      (YYNSTATE+YYNRULE+2)
#define YY_ACCEPT_ACTION  (YYNSTATE+YYNRULE+1)
#define YY_ERROR_ACTION   (YYNSTATE+YYNRULE)

/* The yyzerominor constant is used to initialize instances of
** YYMINORTYPE objects to zero. */
static const YYMINORTYPE yyzerominor = { 0 };


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N < YYNSTATE                  Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   YYNSTATE <= N < YYNSTATE+YYNRULE   Reduce by rule N-YYNSTATE.
**
**   N == YYNSTATE+YYNRULE              A syntax error has occurred.
**
**   N == YYNSTATE+YYNRULE+1            The parser accepts its input.
**
**   N == YYNSTATE+YYNRULE+2            No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as
**
**      yy_action[ yy_shift_ofst[S] + X ]
**
** If the index value yy_shift_ofst[S]+X is out of range or if the value
** yy_lookahead[yy_shift_ofst[S]+X] is not equal to X or if yy_shift_ofst[S]
** is equal to YY_SHIFT_USE_DFLT, it means that the action is not in the table
** and that yy_default[S] should be used instead.  
**
** The formula above is for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
*/
static const YYACTIONTYPE yy_action[] = {
 /*     0 */   304,  940,  176,  615,    2,  150,  214,  439,   24,   24,
 /*    10 */    24,   24,  488,   26,   26,   26,   26,   27,   27,   28,
 /*    20 */    28,   28,   29,  216,  413,  414,  212,  413,  414,  446,
 /*    30 */   452,   31,   26,   26,   26,   26,   27,   27,   28,   28,
 /*    40 */    28,   29,  216,   30,  483,   32,  134,   23,   22,  308,
 /*    50 */   456,  457,  453,  453,   25,   25,   24,   24,   24,   24,
 /*    60 */   436,   26,   26,   26,   26,   27,   27,   28,   28,   28,
 /*    70 */    29,  216,  304,  216,  311,  439,  512,  490,   45,   26,
 /*    80 */    26,   26,   26,   27,   27,   28,   28,   28,   29,  216,
 /*    90 */   413,  414,  416,  417,  156,  416,  417,  360,  363,  364,
 /*   100 */   311,  446,  452,  385,  514,   21,  186,  495,  365,   27,
 /*   110 */    27,   28,   28,   28,   29,  216,  413,  414,  415,   23,
 /*   120 */    22,  308,  456,  457,  453,  453,   25,   25,   24,   24,
 /*   130 */    24,   24,  555,   26,   26,   26,   26,   27,   27,   28,
 /*   140 */    28,   28,   29,  216,  304,  228,  504,  135,  468,  218,
 /*   150 */   548,  145,  132,  256,  358,  261,  359,  153,  416,  417,
 /*   160 */   241,  598,  331,   30,  265,   32,  134,  439,  596,  597,
 /*   170 */   230,  228,  490,  446,  452,   57,  506,  328,  132,  256,
 /*   180 */   358,  261,  359,  153,  416,  417,  435,   78,  408,  405,
 /*   190 */   265,   23,   22,  308,  456,  457,  453,  453,   25,   25,
 /*   200 */    24,   24,   24,   24,  342,   26,   26,   26,   26,   27,
 /*   210 */    27,   28,   28,   28,   29,  216,  304,  214,  534,  547,
 /*   220 */   307,  127,  489,  595,   30,  331,   32,  134,  345,  387,
 /*   230 */   429,   63,  331,  355,  415,  439,  507,  331,  415,  535,
 /*   240 */   328,  215,  193,  594,  593,  446,  452,  328,   18,  435,
 /*   250 */    85,   16,  328,  183,  190,  556,  435,   78,  309,  463,
 /*   260 */   464,  435,   85,   23,   22,  308,  456,  457,  453,  453,
 /*   270 */    25,   25,   24,   24,   24,   24,  436,   26,   26,   26,
 /*   280 */    26,   27,   27,   28,   28,   28,   29,  216,  304,  347,
 /*   290 */   221,  313,  595,  191,  378,  331,  472,  234,  345,  381,
 /*   300 */   324,  410,  220,  344,  592,  217,  213,  415,  112,  331,
 /*   310 */   328,    4,  594,  399,  211,  554,  529,  446,  452,  435,
 /*   320 */    79,  217,  553,  515,  328,  334,  513,  459,  459,  469,
 /*   330 */   441,  572,  432,  435,   78,   23,   22,  308,  456,  457,
 /*   340 */   453,  453,   25,   25,   24,   24,   24,   24,  436,   26,
 /*   350 */    26,   26,   26,   27,   27,   28,   28,   28,   29,  216,
 /*   360 */   304,  443,  443,  443,  156,  468,  218,  360,  363,  364,
 /*   370 */   331,  247,  395,  398,  217,  349,  331,   30,  365,   32,
 /*   380 */   134,  388,  282,  281,   39,  328,   41,  430,  545,  446,
 /*   390 */   452,  328,  214,  531,  435,   93,  542,  601,    1,  404,
 /*   400 */   435,   93,  413,  414,  495,   40,  536,   23,   22,  308,
 /*   410 */   456,  457,  453,  453,   25,   25,   24,   24,   24,   24,
 /*   420 */   573,   26,   26,   26,   26,   27,   27,   28,   28,   28,
 /*   430 */    29,  216,  304,  276,  331,  179,  508,  490,  210,  547,
 /*   440 */   319,  413,  414,  222,  192,  385,  320,  240,  415,  328,
 /*   450 */   557,   63,  413,  414,  415,  616,  408,  405,  435,   71,
 /*   460 */   415,  446,  452,  611,  572,   28,   28,   28,   29,  216,
 /*   470 */   416,  417,  436,  336,  463,  464,  401,   43,  436,   23,
 /*   480 */    22,  308,  456,  457,  453,  453,   25,   25,   24,   24,
 /*   490 */    24,   24,  495,   26,   26,   26,   26,   27,   27,   28,
 /*   500 */    28,   28,   29,  216,  304,  612,  209,  135,  511,  416,
 /*   510 */   417,  431,  233,   64,  388,  282,  281,  439,   66,  542,
 /*   520 */   416,  417,  413,  414,  156,  214,  403,  360,  363,  364,
 /*   530 */   547,  252,  490,  446,  452,  491,  217,    8,  365,  495,
 /*   540 */   436,  606,   63,  537,  299,  415,  492,  470,  546,  200,
 /*   550 */   196,   23,   22,  308,  456,  457,  453,  453,   25,   25,
 /*   560 */    24,   24,   24,   24,  386,   26,   26,   26,   26,   27,
 /*   570 */    27,   28,   28,   28,   29,  216,  304,  477,  254,  354,
 /*   580 */   528,   60,  517,  518,  436,  439,  389,  331,  356,    7,
 /*   590 */   416,  417,  331,  478,  328,  208,  197,  137,  460,  499,
 /*   600 */   447,  448,  328,  435,    9,  446,  452,  328,  479,  485,
 /*   610 */   519,  435,   72,  567,  415,  434,  435,   67,  486,  433,
 /*   620 */   520,  450,  451,   23,   22,  308,  456,  457,  453,  453,
 /*   630 */    25,   25,   24,   24,   24,   24,  331,   26,   26,   26,
 /*   640 */    26,   27,   27,   28,   28,   28,   29,  216,  304,  331,
 /*   650 */   449,  328,  268,  390,  461,  331,   65,  331,  368,  434,
 /*   660 */   435,   76,  310,  433,  328,  150,  427,  439,  473,  331,
 /*   670 */   328,  499,  328,  435,   97,   29,  216,  446,  452,  435,
 /*   680 */    96,  435,  101,  353,  328,  372,  415,  334,  154,  459,
 /*   690 */   459,  352,  569,  435,   99,   23,   22,  308,  456,  457,
 /*   700 */   453,  453,   25,   25,   24,   24,   24,   24,  331,   26,
 /*   710 */    26,   26,   26,   27,   27,   28,   28,   28,   29,  216,
 /*   720 */   304,  331,  248,  328,  264,   56,  334,  331,  459,  459,
 /*   730 */   861,  333,  435,  104,  376,  439,  328,  415,  331,  415,
 /*   740 */   565,  331,  328,  306,  564,  435,  105,  185,  265,  446,
 /*   750 */   452,  435,  126,  328,  570,  518,  328,  334,  377,  459,
 /*   760 */   459,  314,  435,  128,  194,  435,   59,   23,   22,  308,
 /*   770 */   456,  457,  453,  453,   25,   25,   24,   24,   24,   24,
 /*   780 */   331,   26,   26,   26,   26,   27,   27,   28,   28,   28,
 /*   790 */    29,  216,  304,  331,  136,  328,  242,  477,  436,  331,
 /*   800 */   350,  331,  609,  303,  435,  102,  201,  137,  328,  415,
 /*   810 */   454,  178,  331,  478,  328,  415,  328,  435,   77,  440,
 /*   820 */   249,  446,  452,  435,  100,  435,   68,  328,  479,  465,
 /*   830 */   341,  613,  931,  484,  931,  415,  435,   98,  467,   23,
 /*   840 */    22,  308,  456,  457,  453,  453,   25,   25,   24,   24,
 /*   850 */    24,   24,  331,   26,   26,   26,   26,   27,   27,   28,
 /*   860 */    28,   28,   29,  216,  304,  331,  397,  328,  164,  264,
 /*   870 */   205,  331,  264,  332,  610,  339,  435,  129,  407,    2,
 /*   880 */   328,  322,  175,  331,  415,  214,  328,  415,  415,  435,
 /*   890 */   130,  466,  466,  446,  452,  435,  131,  396,  328,  257,
 /*   900 */   334,  487,  459,  459,  436,  154,  229,  435,   69,  315,
 /*   910 */   258,   23,   33,  308,  456,  457,  453,  453,   25,   25,
 /*   920 */    24,   24,   24,   24,  331,   26,   26,   26,   26,   27,
 /*   930 */    27,   28,   28,   28,   29,  216,  304,  331,  497,  328,
 /*   940 */   151,  264,  412,  331,  264,  470,  337,  200,  435,   80,
 /*   950 */   250,  155,  328,  523,  524,  331,  415,  415,  328,  415,
 /*   960 */   306,  435,   81,  533,  532,  446,  452,  435,   70,   47,
 /*   970 */   328,  613,  930,  259,  930,  418,  419,  420,  316,  435,
 /*   980 */    82,  317,  206,  539,   22,  308,  456,  457,  453,  453,
 /*   990 */    25,   25,   24,   24,   24,   24,  331,   26,   26,   26,
 /*  1000 */    26,   27,   27,   28,   28,   28,   29,  216,  304,  331,
 /*  1010 */   209,  328,  529,  540,  610,  331,  436,  563,  375,  563,
 /*  1020 */   435,   83,  362,  538,  328,  155,  541,  331,  499,  526,
 /*  1030 */   328,  331,  575,  435,   84,  424,  543,  446,  452,  435,
 /*  1040 */    86,  290,  328,  415,  436,  267,  328,  155,  394,  141,
 /*  1050 */   415,  435,   87,  588,  411,  435,   88,  308,  456,  457,
 /*  1060 */   453,  453,   25,   25,   24,   24,   24,   24,  386,   26,
 /*  1070 */    26,   26,   26,   27,   27,   28,   28,   28,   29,  216,
 /*  1080 */    35,  338,  286,    3,  331,  270,  331,  327,  414,  421,
 /*  1090 */   382,  318,  276,  422,  325,   35,  338,  335,    3,  328,
 /*  1100 */   423,  328,  327,  414,  142,  144,  276,  415,  435,   73,
 /*  1110 */   435,   74,  335,  331,    6,  340,  425,  331,  326,  331,
 /*  1120 */   367,  415,  155,  437,  289,  472,  287,  274,  328,  272,
 /*  1130 */   340,  415,  328,   47,  328,  277,  276,  435,   89,  348,
 /*  1140 */   472,  435,   90,  435,   91,   38,   37,  243,  331,  582,
 /*  1150 */   244,  415,  426,  276,   36,  329,  330,   46,  245,  441,
 /*  1160 */    38,   37,  505,  328,  202,  203,  204,  415,  415,   36,
 /*  1170 */   329,  330,  435,   92,  441,  198,  568,  214,  155,  584,
 /*  1180 */   235,  236,  237,  143,  239,  346,  133,  581,  438,  246,
 /*  1190 */   443,  443,  443,  444,  445,   10,  585,  276,   20,   42,
 /*  1200 */   172,  415,  294,  331,  288,  443,  443,  443,  444,  445,
 /*  1210 */    10,  295,  415,   35,  338,  219,    3,  149,  328,  482,
 /*  1220 */   327,  414,  331,  170,  276,  572,   48,  435,   75,  169,
 /*  1230 */   335,   19,  171,  251,  442,  413,  414,  328,  331,  415,
 /*  1240 */   586,  343,  276,  177,  351,  496,  435,   17,  340,  415,
 /*  1250 */   481,  253,  255,  328,  276,  502,  415,  415,  472,  331,
 /*  1260 */   503,  357,  435,   94,  576,  415,  151,  231,  312,  415,
 /*  1270 */   577,  516,   54,  472,  328,  393,  291,  281,   38,   37,
 /*  1280 */   494,  305,  521,  435,   95,  232,  214,   36,  329,  330,
 /*  1290 */   526,  498,  441,  188,  189,  415,  500,  292,  522,  262,
 /*  1300 */   530,  260,  263,  513,  549,  269,  415,  441,  589,  400,
 /*  1310 */    54,  415,  525,  527,  415,  415,  271,  415,  273,  415,
 /*  1320 */   415,  275,  280,  443,  443,  443,  444,  445,   10,  107,
 /*  1330 */   380,  415,  383,  415,  384,  283,  415,  415,  443,  443,
 /*  1340 */   443,  284,  285,  580,  300,  415,  591,  415,  293,  415,
 /*  1350 */   415,  296,  297,  605,  226,  550,  415,  415,  415,  225,
 /*  1360 */   608,  415,  302,  415,  551,  227,  415,  415,  415,  301,
 /*  1370 */   544,  552,  369,  158,  373,  558,  159,  278,  371,  160,
 /*  1380 */    51,  207,  560,  561,  161,  140,  379,  117,  571,  163,
 /*  1390 */   391,  392,  181,  180,  321,  602,  578,  118,  119,  120,
 /*  1400 */   121,  123,   55,  587,   58,  603,  604,  607,   62,  174,
 /*  1410 */   103,  224,  111,  409,  238,  428,  199,  323,  657,  658,
 /*  1420 */   659,  146,  147,  455,  458,   34,  474,  462,  471,  182,
 /*  1430 */   195,  148,  475,  476,  480,    5,   12,  493,   44,   11,
 /*  1440 */   106,  138,  509,  510,  501,  223,   49,  361,  108,  109,
 /*  1450 */   152,  266,   50,  110,  157,  258,  370,  184,  559,  139,
 /*  1460 */   151,  113,  279,  162,  115,  374,   15,  574,  116,  165,
 /*  1470 */    52,   13,  366,  579,   53,  167,  168,  166,  583,  124,
 /*  1480 */   114,  122,  562,  566,   14,   61,  599,  600,  125,  173,
 /*  1490 */   298,  590,  187,  406,  941,  614,  941,  402,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */    19,  142,  143,  144,  145,   24,  116,   26,   75,   76,
 /*    10 */    77,   78,   25,   80,   81,   82,   83,   84,   85,   86,
 /*    20 */    87,   88,   89,   90,   26,   27,  160,   26,   27,   48,
 /*    30 */    49,   79,   80,   81,   82,   83,   84,   85,   86,   87,
 /*    40 */    88,   89,   90,  222,  223,  224,  225,   66,   67,   68,
 /*    50 */    69,   70,   71,   72,   73,   74,   75,   76,   77,   78,
 /*    60 */   194,   80,   81,   82,   83,   84,   85,   86,   87,   88,
 /*    70 */    89,   90,   19,   90,   19,   94,  174,   25,   25,   80,
 /*    80 */    81,   82,   83,   84,   85,   86,   87,   88,   89,   90,
 /*    90 */    26,   27,   94,   95,   96,   94,   95,   99,  100,  101,
 /*   100 */    19,   48,   49,  150,  174,   52,  119,  166,  110,   84,
 /*   110 */    85,   86,   87,   88,   89,   90,   26,   27,  165,   66,
 /*   120 */    67,   68,   69,   70,   71,   72,   73,   74,   75,   76,
 /*   130 */    77,   78,  186,   80,   81,   82,   83,   84,   85,   86,
 /*   140 */    87,   88,   89,   90,   19,   90,  205,   95,   84,   85,
 /*   150 */   186,   96,   97,   98,   99,  100,  101,  102,   94,   95,
 /*   160 */   195,   97,  150,  222,  109,  224,  225,   26,  104,  105,
 /*   170 */   217,   90,  120,   48,   49,   50,   86,  165,   97,   98,
 /*   180 */    99,  100,  101,  102,   94,   95,  174,  175,    1,    2,
 /*   190 */   109,   66,   67,   68,   69,   70,   71,   72,   73,   74,
 /*   200 */    75,   76,   77,   78,  191,   80,   81,   82,   83,   84,
 /*   210 */    85,   86,   87,   88,   89,   90,   19,  116,   35,  150,
 /*   220 */   155,   24,  208,  150,  222,  150,  224,  225,  216,  128,
 /*   230 */   161,  162,  150,  221,  165,   94,   23,  150,  165,   56,
 /*   240 */   165,  197,  160,  170,  171,   48,   49,  165,  204,  174,
 /*   250 */   175,   22,  165,   24,  185,  186,  174,  175,  169,  170,
 /*   260 */   171,  174,  175,   66,   67,   68,   69,   70,   71,   72,
 /*   270 */    73,   74,   75,   76,   77,   78,  194,   80,   81,   82,
 /*   280 */    83,   84,   85,   86,   87,   88,   89,   90,   19,  214,
 /*   290 */   215,  108,  150,   25,  229,  150,   64,  148,  216,  234,
 /*   300 */   146,  147,  215,  221,  231,  232,  152,  165,  154,  150,
 /*   310 */   165,  196,  170,  171,  160,  181,  182,   48,   49,  174,
 /*   320 */   175,  232,  188,  165,  165,  112,   94,  114,  115,  166,
 /*   330 */    98,   55,  174,  174,  175,   66,   67,   68,   69,   70,
 /*   340 */    71,   72,   73,   74,   75,   76,   77,   78,  194,   80,
 /*   350 */    81,   82,   83,   84,   85,   86,   87,   88,   89,   90,
 /*   360 */    19,  129,  130,  131,   96,   84,   85,   99,  100,  101,
 /*   370 */   150,  226,  218,  231,  232,  216,  150,  222,  110,  224,
 /*   380 */   225,  105,  106,  107,  135,  165,  137,  172,  173,   48,
 /*   390 */    49,  165,  116,  183,  174,  175,  181,  242,   22,  245,
 /*   400 */   174,  175,   26,   27,  166,  136,  183,   66,   67,   68,
 /*   410 */    69,   70,   71,   72,   73,   74,   75,   76,   77,   78,
 /*   420 */    11,   80,   81,   82,   83,   84,   85,   86,   87,   88,
 /*   430 */    89,   90,   19,  150,  150,   23,   23,   25,  160,  150,
 /*   440 */   220,   26,   27,  205,  160,  150,  220,  158,  165,  165,
 /*   450 */   161,  162,   26,   27,  165,    0,    1,    2,  174,  175,
 /*   460 */   165,   48,   49,   23,   55,   86,   87,   88,   89,   90,
 /*   470 */    94,   95,  194,  169,  170,  171,  193,  136,  194,   66,
 /*   480 */    67,   68,   69,   70,   71,   72,   73,   74,   75,   76,
 /*   490 */    77,   78,  166,   80,   81,   82,   83,   84,   85,   86,
 /*   500 */    87,   88,   89,   90,   19,   65,  160,   95,   23,   94,
 /*   510 */    95,  173,  217,   22,  105,  106,  107,   26,   22,  181,
 /*   520 */    94,   95,   26,   27,   96,  116,  243,   99,  100,  101,
 /*   530 */   150,  205,  120,   48,   49,  120,  232,   22,  110,  166,
 /*   540 */   194,  161,  162,  183,  163,  165,  120,  166,  167,  168,
 /*   550 */   160,   66,   67,   68,   69,   70,   71,   72,   73,   74,
 /*   560 */    75,   76,   77,   78,  218,   80,   81,   82,   83,   84,
 /*   570 */    85,   86,   87,   88,   89,   90,   19,   12,  205,  150,
 /*   580 */    23,  235,  190,  191,  194,   94,  240,  150,   86,   74,
 /*   590 */    94,   95,  150,   28,  165,  236,  206,  207,   23,  150,
 /*   600 */    48,   49,  165,  174,  175,   48,   49,  165,   43,   31,
 /*   610 */    45,  174,  175,   21,  165,  113,  174,  175,   40,  117,
 /*   620 */    55,   69,   70,   66,   67,   68,   69,   70,   71,   72,
 /*   630 */    73,   74,   75,   76,   77,   78,  150,   80,   81,   82,
 /*   640 */    83,   84,   85,   86,   87,   88,   89,   90,   19,  150,
 /*   650 */    98,  165,   23,   61,   23,  150,   25,  150,   19,  113,
 /*   660 */   174,  175,  213,  117,  165,   24,  153,   26,   23,  150,
 /*   670 */   165,  150,  165,  174,  175,   89,   90,   48,   49,  174,
 /*   680 */   175,  174,  175,   19,  165,  237,  165,  112,   49,  114,
 /*   690 */   115,   27,  100,  174,  175,   66,   67,   68,   69,   70,
 /*   700 */    71,   72,   73,   74,   75,   76,   77,   78,  150,   80,
 /*   710 */    81,   82,   83,   84,   85,   86,   87,   88,   89,   90,
 /*   720 */    19,  150,  150,  165,  150,   24,  112,  150,  114,  115,
 /*   730 */   138,   19,  174,  175,  213,   94,  165,  165,  150,  165,
 /*   740 */    29,  150,  165,  104,   33,  174,  175,  196,  109,   48,
 /*   750 */    49,  174,  175,  165,  190,  191,  165,  112,   47,  114,
 /*   760 */   115,  187,  174,  175,  160,  174,  175,   66,   67,   68,
 /*   770 */    69,   70,   71,   72,   73,   74,   75,   76,   77,   78,
 /*   780 */   150,   80,   81,   82,   83,   84,   85,   86,   87,   88,
 /*   790 */    89,   90,   19,  150,  150,  165,  198,   12,  194,  150,
 /*   800 */   150,  150,  248,  249,  174,  175,  206,  207,  165,  165,
 /*   810 */    98,   23,  150,   28,  165,  165,  165,  174,  175,  166,
 /*   820 */   150,   48,   49,  174,  175,  174,  175,  165,   43,  233,
 /*   830 */    45,   22,   23,  177,   25,  165,  174,  175,  233,   66,
 /*   840 */    67,   68,   69,   70,   71,   72,   73,   74,   75,   76,
 /*   850 */    77,   78,  150,   80,   81,   82,   83,   84,   85,   86,
 /*   860 */    87,   88,   89,   90,   19,  150,   97,  165,   25,  150,
 /*   870 */   160,  150,  150,  150,   65,  228,  174,  175,  144,  145,
 /*   880 */   165,  246,  247,  150,  165,  116,  165,  165,  165,  174,
 /*   890 */   175,  129,  130,   48,   49,  174,  175,  128,  165,   98,
 /*   900 */   112,  177,  114,  115,  194,   49,  187,  174,  175,  187,
 /*   910 */   109,   66,   67,   68,   69,   70,   71,   72,   73,   74,
 /*   920 */    75,   76,   77,   78,  150,   80,   81,   82,   83,   84,
 /*   930 */    85,   86,   87,   88,   89,   90,   19,  150,   23,  165,
 /*   940 */    25,  150,  150,  150,  150,  166,  167,  168,  174,  175,
 /*   950 */   209,   25,  165,    7,    8,  150,  165,  165,  165,  165,
 /*   960 */   104,  174,  175,   97,   98,   48,   49,  174,  175,  126,
 /*   970 */   165,   22,   23,  177,   25,    7,    8,    9,  187,  174,
 /*   980 */   175,  187,  160,  177,   67,   68,   69,   70,   71,   72,
 /*   990 */    73,   74,   75,   76,   77,   78,  150,   80,   81,   82,
 /*  1000 */    83,   84,   85,   86,   87,   88,   89,   90,   19,  150,
 /*  1010 */   160,  165,  182,  166,   65,  150,  194,  105,  106,  107,
 /*  1020 */   174,  175,  178,   23,  165,   25,  177,  150,  150,  103,
 /*  1030 */   165,  150,  199,  174,  175,  150,  166,   48,   49,  174,
 /*  1040 */   175,  209,  165,  165,  194,   23,  165,   25,  209,    6,
 /*  1050 */   165,  174,  175,  199,  149,  174,  175,   68,   69,   70,
 /*  1060 */    71,   72,   73,   74,   75,   76,   77,   78,  218,   80,
 /*  1070 */    81,   82,   83,   84,   85,   86,   87,   88,   89,   90,
 /*  1080 */    19,   20,   16,   22,  150,   16,  150,   26,   27,  149,
 /*  1090 */   240,  213,  150,  149,  149,   19,   20,   36,   22,  165,
 /*  1100 */    13,  165,   26,   27,  151,  151,  150,  165,  174,  175,
 /*  1110 */   174,  175,   36,  150,   25,   54,  150,  150,  159,  150,
 /*  1120 */    23,  165,   25,  194,   58,   64,   60,   58,  165,   60,
 /*  1130 */    54,  165,  165,  126,  165,  193,  150,  174,  175,  123,
 /*  1140 */    64,  174,  175,  174,  175,   84,   85,  199,  150,  193,
 /*  1150 */   200,  165,  150,  150,   93,   94,   95,  124,  201,   98,
 /*  1160 */    84,   85,   86,  165,  105,  106,  107,  165,  165,   93,
 /*  1170 */    94,   95,  174,  175,   98,    5,   23,  116,   25,  193,
 /*  1180 */    10,   11,   12,   13,   14,  122,  150,   17,  203,  202,
 /*  1190 */   129,  130,  131,  132,  133,  134,  193,  150,  125,  135,
 /*  1200 */    30,  165,   32,  150,  138,  129,  130,  131,  132,  133,
 /*  1210 */   134,   41,  165,   19,   20,  227,   22,  118,  165,  157,
 /*  1220 */    26,   27,  150,   53,  150,   55,  104,  174,  175,   59,
 /*  1230 */    36,   22,   62,  210,  150,   26,   27,  165,  150,  165,
 /*  1240 */   193,  150,  150,  157,  121,  211,  174,  175,   54,  165,
 /*  1250 */   150,  210,  210,  165,  150,  211,  165,  165,   64,  150,
 /*  1260 */   211,  104,  174,  175,   23,  165,   25,  193,   46,  165,
 /*  1270 */    23,  176,   25,   64,  165,  105,  106,  107,   84,   85,
 /*  1280 */   150,  111,  176,  174,  175,  193,  116,   93,   94,   95,
 /*  1290 */   103,  150,   98,   84,   85,  165,  150,  193,  184,  150,
 /*  1300 */   150,  176,  150,   94,  150,  150,  165,   98,   23,  139,
 /*  1310 */    25,  165,  178,  176,  165,  165,  150,  165,  150,  165,
 /*  1320 */   165,  150,  150,  129,  130,  131,  132,  133,  134,   22,
 /*  1330 */   150,  165,  150,  165,  150,  150,  165,  165,  129,  130,
 /*  1340 */   131,  150,  150,  150,  179,  165,  150,  165,  150,  165,
 /*  1350 */   165,  150,  150,  150,   90,  176,  165,  165,  165,  230,
 /*  1360 */    23,  165,   25,  165,  176,  230,  165,  165,  165,  179,
 /*  1370 */   184,  176,   18,  156,   44,  157,  156,  238,  157,  156,
 /*  1380 */   135,  157,  157,  239,  156,   66,  157,   22,  189,  189,
 /*  1390 */   157,   18,  219,  219,  157,   39,  199,  192,  192,  192,
 /*  1400 */   192,  189,  241,  199,  241,  157,  157,   37,  244,  247,
 /*  1410 */   164,  180,  180,    1,   15,   23,   22,  250,  118,  118,
 /*  1420 */   118,  118,  118,   98,  113,   22,   11,   23,   23,   22,
 /*  1430 */    22,   25,   23,   23,   23,   34,   34,  120,   25,   25,
 /*  1440 */    22,  118,   23,   23,   27,   50,   22,   50,   22,   22,
 /*  1450 */    34,   23,   22,   22,  102,  109,   19,   24,   20,   38,
 /*  1460 */    25,  104,  138,  104,   22,   42,    5,    1,  108,  127,
 /*  1470 */    74,   22,   50,    1,   74,   16,  121,  119,   20,  108,
 /*  1480 */    51,  119,   57,   51,   22,   16,   23,   23,  127,   15,
 /*  1490 */   140,  128,   22,    3,  251,    4,  251,   63,
};
#define YY_SHIFT_USE_DFLT (-111)
#define YY_SHIFT_MAX 406
static const short yy_shift_ofst[] = {
 /*     0 */   187, 1061, 1170, 1061, 1194, 1194,   -2,   64,   64,  -19,
 /*    10 */  1194, 1194, 1194, 1194, 1194,  276,    1,  125, 1076, 1194,
 /*    20 */  1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194,
 /*    30 */  1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194,
 /*    40 */  1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194,
 /*    50 */  1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194,  -48,
 /*    60 */   409,    1,    1,  141,  281,  281, -110,   53,  197,  269,
 /*    70 */   341,  413,  485,  557,  629,  701,  773,  845,  773,  773,
 /*    80 */   773,  773,  773,  773,  773,  773,  773,  773,  773,  773,
 /*    90 */   773,  773,  773,  773,  773,  773,  917,  989,  989,  -67,
 /*   100 */   -67,   -1,   -1,   55,   25,  379,    1,    1,    1,    1,
 /*   110 */     1,  639,  592,    1,    1,    1,    1,    1,    1,    1,
 /*   120 */     1,    1,    1,    1,    1,    1,  586,  141,  -17, -111,
 /*   130 */  -111, -111, 1209,   81,  376,  415,  426,  496,   90,  565,
 /*   140 */   565,    1,    1,    1,    1,    1,    1,    1,    1,    1,
 /*   150 */     1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
 /*   160 */     1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
 /*   170 */     1,    1,    1,    1,  809,  949,  455,  641,  641,  641,
 /*   180 */   769,  101, -110, -110, -110, -111, -111, -111,  232,  232,
 /*   190 */   268,  428,  213,  575,  645,  785,  788,  412,  968,  502,
 /*   200 */   491,   52,  183,  183,  183,  614,  614,  711,  912,  614,
 /*   210 */   614,  614,  614,  229,  546,  -13,  141,  762,  762,  249,
 /*   220 */   578,  578,  664,  578,  856,  578,  141,  578,  141,  926,
 /*   230 */   843,  664,  664,  843, 1043, 1043, 1043, 1043, 1087, 1087,
 /*   240 */  1089, -110, 1007, 1016, 1033, 1063, 1073, 1064, 1099, 1099,
 /*   250 */  1122, 1123, 1122, 1123, 1122, 1123, 1157, 1157, 1222, 1157,
 /*   260 */  1187, 1157, 1307, 1264, 1264, 1222, 1157, 1157, 1157, 1307,
 /*   270 */  1354, 1099, 1354, 1099, 1354, 1099, 1099, 1330, 1245, 1354,
 /*   280 */  1099, 1319, 1319, 1365, 1007, 1099, 1373, 1373, 1373, 1373,
 /*   290 */  1007, 1319, 1365, 1099, 1356, 1356, 1099, 1099, 1370, -111,
 /*   300 */  -111, -111, -111, -111,  552, 1066, 1059, 1069,  712,  631,
 /*   310 */   915,  801,  946,  866, 1000, 1022, 1097, 1153, 1241, 1247,
 /*   320 */  1285,  515, 1337,  440, 1412, 1399, 1392, 1394, 1300, 1301,
 /*   330 */  1302, 1303, 1304, 1325, 1311, 1403, 1404, 1405, 1407, 1415,
 /*   340 */  1408, 1409, 1406, 1410, 1411, 1413, 1401, 1414, 1402, 1413,
 /*   350 */  1317, 1418, 1416, 1417, 1323, 1419, 1420, 1421, 1395, 1424,
 /*   360 */  1397, 1426, 1428, 1427, 1430, 1422, 1431, 1352, 1346, 1437,
 /*   370 */  1438, 1433, 1357, 1423, 1425, 1429, 1435, 1432, 1324, 1359,
 /*   380 */  1442, 1461, 1466, 1360, 1396, 1400, 1342, 1449, 1358, 1472,
 /*   390 */  1459, 1355, 1458, 1362, 1371, 1361, 1462, 1363, 1463, 1464,
 /*   400 */  1469, 1434, 1474, 1350, 1470, 1490, 1491,
};
#define YY_REDUCE_USE_DFLT (-180)
#define YY_REDUCE_MAX 303
static const short yy_reduce_ofst[] = {
 /*     0 */  -141,   82,  154,  284,   12,   75,   69,   73,  142,  -59,
 /*    10 */   145,   87,  159,  220,  226,  346,  289,  155,  429,  437,
 /*    20 */   442,  486,  499,  505,  507,  519,  558,  571,  577,  588,
 /*    30 */   591,  630,  643,  649,  651,  662,  702,  715,  721,  733,
 /*    40 */   774,  787,  793,  805,  846,  859,  865,  877,  881,  934,
 /*    50 */   936,  963,  967,  969,  998, 1053, 1072, 1088, 1109, -179,
 /*    60 */   850,  283,  380,  381,   89,  304,  390,    2,    2,    2,
 /*    70 */     2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
 /*    80 */     2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
 /*    90 */     2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
 /*   100 */     2,    2,    2,  215,    2,    2,  449,  574,  719,  722,
 /*   110 */   791,  134,   65,  942,  521,  794,  -47,  878,  956,  986,
 /*   120 */  1003, 1047, 1074, 1092,  295, 1104,    2,  779,    2,    2,
 /*   130 */     2,    2,  158,  338,  572,  644,  650,  670,  723,  392,
 /*   140 */   564,  792,  885,  966, 1002, 1036,  723, 1084, 1091, 1100,
 /*   150 */  1130, 1141, 1146, 1149, 1150, 1152, 1154, 1155, 1166, 1168,
 /*   160 */  1171, 1172, 1180, 1182, 1184, 1185, 1191, 1192, 1193, 1196,
 /*   170 */  1198, 1201, 1202, 1203,  554,  554,  734,  238,  326,  373,
 /*   180 */  -134,  278,  604,  710,  822,   44,  600,  635,  -98,  -70,
 /*   190 */   -54,  -36,  -35,  -35,  -35,   13,  -35,   14,  149,  115,
 /*   200 */   163,   14,  210,  223,  360,  -35,  -35,  359,  448,  -35,
 /*   210 */   -35,  -35,  -35,  513,  551,  598,  653,  596,  605,  647,
 /*   220 */   656,  724,  741,  796,  830,  806,  847,  849,  870,  844,
 /*   230 */   833,  832,  839,  854,  905,  940,  944,  945,  953,  954,
 /*   240 */   959,  929,  948,  950,  957,  987,  985,  988, 1062, 1086,
 /*   250 */  1023, 1034, 1041, 1044, 1042, 1049, 1095, 1106, 1114, 1125,
 /*   260 */  1134, 1137, 1165, 1129, 1135, 1186, 1179, 1188, 1195, 1190,
 /*   270 */  1217, 1218, 1220, 1221, 1223, 1224, 1225, 1139, 1144, 1228,
 /*   280 */  1229, 1199, 1200, 1173, 1197, 1233, 1205, 1206, 1207, 1208,
 /*   290 */  1204, 1212, 1174, 1237, 1161, 1163, 1248, 1249, 1164, 1246,
 /*   300 */  1231, 1232, 1162, 1167,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */   621,  856,  939,  939,  856,  939,  939,  885,  885,  744,
 /*    10 */   854,  939,  939,  939,  939,  939,  939,  914,  939,  939,
 /*    20 */   939,  939,  939,  939,  939,  939,  939,  939,  939,  939,
 /*    30 */   939,  939,  939,  939,  939,  939,  939,  939,  939,  939,
 /*    40 */   939,  939,  939,  939,  939,  939,  939,  939,  939,  939,
 /*    50 */   939,  939,  939,  939,  939,  939,  939,  939,  939,  828,
 /*    60 */   939,  939,  939,  660,  885,  885,  748,  779,  939,  939,
 /*    70 */   939,  939,  939,  939,  939,  939,  780,  939,  858,  853,
 /*    80 */   849,  851,  850,  857,  781,  770,  777,  784,  759,  898,
 /*    90 */   786,  787,  793,  794,  915,  913,  816,  815,  834,  818,
 /*   100 */   840,  817,  827,  652,  819,  820,  939,  939,  939,  939,
 /*   110 */   939,  713,  647,  939,  939,  939,  939,  939,  939,  939,
 /*   120 */   939,  939,  939,  939,  939,  939,  821,  939,  822,  835,
 /*   130 */   836,  837,  939,  939,  939,  939,  939,  939,  939,  939,
 /*   140 */   939,  627,  939,  939,  939,  939,  939,  939,  939,  939,
 /*   150 */   939,  939,  939,  939,  939,  939,  939,  939,  939,  939,
 /*   160 */   939,  939,  939,  939,  939,  939,  939,  939,  939,  869,
 /*   170 */   939,  918,  920,  939,  939,  939,  621,  744,  744,  744,
 /*   180 */   939,  939,  939,  939,  939,  738,  748,  932,  939,  939,
 /*   190 */   704,  939,  939,  939,  939,  939,  939,  939,  629,  736,
 /*   200 */   662,  746,  939,  939,  939,  649,  725,  891,  939,  905,
 /*   210 */   903,  727,  789,  939,  736,  745,  939,  939,  939,  852,
 /*   220 */   773,  773,  761,  773,  683,  773,  939,  773,  939,  686,
 /*   230 */   783,  761,  761,  783,  626,  626,  626,  626,  637,  637,
 /*   240 */   703,  939,  783,  774,  776,  766,  778,  939,  752,  752,
 /*   250 */   760,  765,  760,  765,  760,  765,  715,  715,  700,  715,
 /*   260 */   686,  715,  862,  866,  866,  700,  715,  715,  715,  862,
 /*   270 */   644,  752,  644,  752,  644,  752,  752,  895,  897,  644,
 /*   280 */   752,  717,  717,  795,  783,  752,  724,  724,  724,  724,
 /*   290 */   783,  717,  795,  752,  917,  917,  752,  752,  925,  670,
 /*   300 */   688,  688,  932,  937,  939,  939,  939,  939,  939,  939,
 /*   310 */   939,  939,  939,  939,  939,  939,  939,  939,  939,  939,
 /*   320 */   939,  871,  939,  939,  939,  635,  939,  654,  802,  807,
 /*   330 */   803,  939,  804,  939,  730,  939,  939,  939,  939,  939,
 /*   340 */   939,  939,  939,  939,  939,  855,  939,  767,  939,  775,
 /*   350 */   939,  939,  939,  939,  939,  939,  939,  939,  939,  939,
 /*   360 */   939,  939,  939,  939,  939,  939,  939,  939,  939,  939,
 /*   370 */   939,  939,  939,  939,  939,  893,  894,  939,  939,  939,
 /*   380 */   939,  939,  939,  939,  939,  939,  939,  939,  939,  939,
 /*   390 */   939,  939,  939,  939,  939,  939,  939,  939,  939,  939,
 /*   400 */   939,  924,  939,  939,  927,  622,  939,  617,  619,  620,
 /*   410 */   624,  625,  628,  654,  655,  657,  658,  659,  630,  631,
 /*   420 */   632,  633,  634,  636,  640,  638,  639,  641,  648,  650,
 /*   430 */   669,  671,  673,  734,  735,  799,  728,  729,  733,  656,
 /*   440 */   810,  801,  805,  806,  808,  809,  823,  824,  826,  832,
 /*   450 */   839,  842,  825,  830,  831,  833,  838,  841,  731,  732,
 /*   460 */   845,  663,  664,  667,  668,  881,  883,  882,  884,  666,
 /*   470 */   665,  811,  814,  847,  848,  906,  907,  908,  909,  910,
 /*   480 */   843,  753,  846,  829,  768,  771,  772,  769,  737,  747,
 /*   490 */   755,  756,  757,  758,  742,  743,  749,  764,  797,  798,
 /*   500 */   762,  763,  750,  751,  739,  740,  741,  844,  800,  812,
 /*   510 */   813,  674,  675,  807,  676,  677,  678,  716,  719,  720,
 /*   520 */   721,  679,  698,  701,  702,  680,  687,  681,  682,  689,
 /*   530 */   690,  691,  694,  695,  696,  697,  692,  693,  863,  864,
 /*   540 */   867,  865,  684,  685,  699,  672,  661,  653,  705,  708,
 /*   550 */   709,  710,  711,  712,  714,  706,  707,  651,  642,  645,
 /*   560 */   754,  887,  896,  892,  888,  889,  890,  646,  859,  860,
 /*   570 */   718,  791,  792,  886,  899,  901,  796,  902,  904,  900,
 /*   580 */   929,  643,  722,  723,  726,  868,  911,  782,  785,  788,
 /*   590 */   790,  870,  872,  874,  876,  877,  878,  879,  880,  873,
 /*   600 */   875,  912,  916,  919,  921,  922,  923,  926,  928,  933,
 /*   610 */   934,  935,  938,  936,  623,  618,
};
#define YY_SZ_ACTTAB (int)(sizeof(yy_action)/sizeof(yy_action[0]))

/* The next table maps tokens into fallback tokens.  If a construct
** like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*       SEMI => nothing */
   26,  /*    EXPLAIN => ID */
   26,  /*      QUERY => ID */
   26,  /*       PLAN => ID */
   26,  /*      BEGIN => ID */
    0,  /* TRANSACTION => nothing */
   26,  /*   DEFERRED => ID */
   26,  /*  IMMEDIATE => ID */
   26,  /*  EXCLUSIVE => ID */
    0,  /*     COMMIT => nothing */
   26,  /*        END => ID */
   26,  /*   ROLLBACK => ID */
   26,  /*  SAVEPOINT => ID */
   26,  /*    RELEASE => ID */
    0,  /*         TO => nothing */
    0,  /*      TABLE => nothing */
    0,  /*     CREATE => nothing */
   26,  /*         IF => ID */
    0,  /*        NOT => nothing */
    0,  /*     EXISTS => nothing */
   26,  /*       TEMP => ID */
    0,  /*         LP => nothing */
    0,  /*         RP => nothing */
    0,  /*         AS => nothing */
    0,  /*      COMMA => nothing */
    0,  /*         ID => nothing */
    0,  /*    INDEXED => nothing */
   26,  /*      ABORT => ID */
   26,  /*      AFTER => ID */
   26,  /*    ANALYZE => ID */
   26,  /*        ASC => ID */
   26,  /*     ATTACH => ID */
   26,  /*     BEFORE => ID */
   26,  /*         BY => ID */
   26,  /*    CASCADE => ID */
   26,  /*       CAST => ID */
   26,  /*   COLUMNKW => ID */
   26,  /*   CONFLICT => ID */
   26,  /*   DATABASE => ID */
   26,  /*       DESC => ID */
   26,  /*     DETACH => ID */
   26,  /*       EACH => ID */
   26,  /*       FAIL => ID */
   26,  /*        FOR => ID */
   26,  /*     IGNORE => ID */
   26,  /*  INITIALLY => ID */
   26,  /*    INSTEAD => ID */
   26,  /*    LIKE_KW => ID */
   26,  /*      MATCH => ID */
   26,  /*        KEY => ID */
   26,  /*         OF => ID */
   26,  /*     OFFSET => ID */
   26,  /*     PRAGMA => ID */
   26,  /*      RAISE => ID */
   26,  /*    REPLACE => ID */
   26,  /*   RESTRICT => ID */
   26,  /*        ROW => ID */
   26,  /*    TRIGGER => ID */
   26,  /*     VACUUM => ID */
   26,  /*       VIEW => ID */
   26,  /*    VIRTUAL => ID */
   26,  /*    REINDEX => ID */
   26,  /*     RENAME => ID */
   26,  /*   CTIME_KW => ID */
    0,  /*        ANY => nothing */
    0,  /*         OR => nothing */
    0,  /*        AND => nothing */
    0,  /*         IS => nothing */
    0,  /*    BETWEEN => nothing */
    0,  /*         IN => nothing */
    0,  /*     ISNULL => nothing */
    0,  /*    NOTNULL => nothing */
    0,  /*         NE => nothing */
    0,  /*         EQ => nothing */
    0,  /*         GT => nothing */
    0,  /*         LE => nothing */
    0,  /*         LT => nothing */
    0,  /*         GE => nothing */
    0,  /*     ESCAPE => nothing */
    0,  /*     BITAND => nothing */
    0,  /*      BITOR => nothing */
    0,  /*     LSHIFT => nothing */
    0,  /*     RSHIFT => nothing */
    0,  /*       PLUS => nothing */
    0,  /*      MINUS => nothing */
    0,  /*       STAR => nothing */
    0,  /*      SLASH => nothing */
    0,  /*        REM => nothing */
    0,  /*     CONCAT => nothing */
    0,  /*    COLLATE => nothing */
    0,  /*     UMINUS => nothing */
    0,  /*      UPLUS => nothing */
    0,  /*     BITNOT => nothing */
    0,  /*     STRING => nothing */
    0,  /*    JOIN_KW => nothing */
    0,  /* CONSTRAINT => nothing */
    0,  /*    DEFAULT => nothing */
    0,  /*       NULL => nothing */
    0,  /*    PRIMARY => nothing */
    0,  /*     UNIQUE => nothing */
    0,  /*      CHECK => nothing */
    0,  /* REFERENCES => nothing */
    0,  /*   AUTOINCR => nothing */
    0,  /*         ON => nothing */
    0,  /*     DELETE => nothing */
    0,  /*     UPDATE => nothing */
    0,  /*     INSERT => nothing */
    0,  /*        SET => nothing */
    0,  /* DEFERRABLE => nothing */
    0,  /*    FOREIGN => nothing */
    0,  /*       DROP => nothing */
    0,  /*      UNION => nothing */
    0,  /*        ALL => nothing */
    0,  /*     EXCEPT => nothing */
    0,  /*  INTERSECT => nothing */
    0,  /*     SELECT => nothing */
    0,  /*   DISTINCT => nothing */
    0,  /*        DOT => nothing */
    0,  /*       FROM => nothing */
    0,  /*       JOIN => nothing */
    0,  /*      USING => nothing */
    0,  /*      ORDER => nothing */
    0,  /*      GROUP => nothing */
    0,  /*     HAVING => nothing */
    0,  /*      LIMIT => nothing */
    0,  /*      WHERE => nothing */
    0,  /*       INTO => nothing */
    0,  /*     VALUES => nothing */
    0,  /*    INTEGER => nothing */
    0,  /*      FLOAT => nothing */
    0,  /*       BLOB => nothing */
    0,  /*   REGISTER => nothing */
    0,  /*   VARIABLE => nothing */
    0,  /*       CASE => nothing */
    0,  /*       WHEN => nothing */
    0,  /*       THEN => nothing */
    0,  /*       ELSE => nothing */
    0,  /*      INDEX => nothing */
    0,  /*      ALTER => nothing */
    0,  /*        ADD => nothing */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  int yyidx;                    /* Index of top element in stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyidxMax;                 /* Maximum value of yyidx */
#endif
  int yyerrcnt;                 /* Shifts left before out of the error */
  sqlite3ParserARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void sqlite3ParserTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "SEMI",          "EXPLAIN",       "QUERY",       
  "PLAN",          "BEGIN",         "TRANSACTION",   "DEFERRED",    
  "IMMEDIATE",     "EXCLUSIVE",     "COMMIT",        "END",         
  "ROLLBACK",      "SAVEPOINT",     "RELEASE",       "TO",          
  "TABLE",         "CREATE",        "IF",            "NOT",         
  "EXISTS",        "TEMP",          "LP",            "RP",          
  "AS",            "COMMA",         "ID",            "INDEXED",     
  "ABORT",         "AFTER",         "ANALYZE",       "ASC",         
  "ATTACH",        "BEFORE",        "BY",            "CASCADE",     
  "CAST",          "COLUMNKW",      "CONFLICT",      "DATABASE",    
  "DESC",          "DETACH",        "EACH",          "FAIL",        
  "FOR",           "IGNORE",        "INITIALLY",     "INSTEAD",     
  "LIKE_KW",       "MATCH",         "KEY",           "OF",          
  "OFFSET",        "PRAGMA",        "RAISE",         "REPLACE",     
  "RESTRICT",      "ROW",           "TRIGGER",       "VACUUM",      
  "VIEW",          "VIRTUAL",       "REINDEX",       "RENAME",      
  "CTIME_KW",      "ANY",           "OR",            "AND",         
  "IS",            "BETWEEN",       "IN",            "ISNULL",      
  "NOTNULL",       "NE",            "EQ",            "GT",          
  "LE",            "LT",            "GE",            "ESCAPE",      
  "BITAND",        "BITOR",         "LSHIFT",        "RSHIFT",      
  "PLUS",          "MINUS",         "STAR",          "SLASH",       
  "REM",           "CONCAT",        "COLLATE",       "UMINUS",      
  "UPLUS",         "BITNOT",        "STRING",        "JOIN_KW",     
  "CONSTRAINT",    "DEFAULT",       "NULL",          "PRIMARY",     
  "UNIQUE",        "CHECK",         "REFERENCES",    "AUTOINCR",    
  "ON",            "DELETE",        "UPDATE",        "INSERT",      
  "SET",           "DEFERRABLE",    "FOREIGN",       "DROP",        
  "UNION",         "ALL",           "EXCEPT",        "INTERSECT",   
  "SELECT",        "DISTINCT",      "DOT",           "FROM",        
  "JOIN",          "USING",         "ORDER",         "GROUP",       
  "HAVING",        "LIMIT",         "WHERE",         "INTO",        
  "VALUES",        "INTEGER",       "FLOAT",         "BLOB",        
  "REGISTER",      "VARIABLE",      "CASE",          "WHEN",        
  "THEN",          "ELSE",          "INDEX",         "ALTER",       
  "ADD",           "error",         "input",         "cmdlist",     
  "ecmd",          "explain",       "cmdx",          "cmd",         
  "transtype",     "trans_opt",     "nm",            "savepoint_opt",
  "create_table",  "create_table_args",  "createkw",      "temp",        
  "ifnotexists",   "dbnm",          "columnlist",    "conslist_opt",
  "select",        "column",        "columnid",      "type",        
  "carglist",      "id",            "ids",           "typetoken",   
  "typename",      "signed",        "plus_num",      "minus_num",   
  "carg",          "ccons",         "term",          "expr",        
  "onconf",        "sortorder",     "autoinc",       "idxlist_opt", 
  "refargs",       "defer_subclause",  "refarg",        "refact",      
  "init_deferred_pred_opt",  "conslist",      "tcons",         "idxlist",     
  "defer_subclause_opt",  "orconf",        "resolvetype",   "raisetype",   
  "ifexists",      "fullname",      "oneselect",     "multiselect_op",
  "distinct",      "selcollist",    "from",          "where_opt",   
  "groupby_opt",   "having_opt",    "orderby_opt",   "limit_opt",   
  "sclp",          "as",            "seltablist",    "stl_prefix",  
  "joinop",        "indexed_opt",   "on_opt",        "using_opt",   
  "joinop2",       "inscollist",    "sortlist",      "sortitem",    
  "nexprlist",     "setlist",       "insert_cmd",    "inscollist_opt",
  "itemlist",      "exprlist",      "likeop",        "escape",      
  "between_op",    "in_op",         "case_operand",  "case_exprlist",
  "case_else",     "uniqueflag",    "collate",       "nmnum",       
  "plus_opt",      "number",        "trigger_decl",  "trigger_cmd_list",
  "trigger_time",  "trigger_event",  "foreach_clause",  "when_clause", 
  "trigger_cmd",   "database_kw_opt",  "key_opt",       "add_column_fullname",
  "kwcolumn_opt",  "create_vtab",   "vtabarglist",   "vtabarg",     
  "vtabargtoken",  "lp",            "anylist",     
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "input ::= cmdlist",
 /*   1 */ "cmdlist ::= cmdlist ecmd",
 /*   2 */ "cmdlist ::= ecmd",
 /*   3 */ "ecmd ::= SEMI",
 /*   4 */ "ecmd ::= explain cmdx SEMI",
 /*   5 */ "explain ::=",
 /*   6 */ "explain ::= EXPLAIN",
 /*   7 */ "explain ::= EXPLAIN QUERY PLAN",
 /*   8 */ "cmdx ::= cmd",
 /*   9 */ "cmd ::= BEGIN transtype trans_opt",
 /*  10 */ "trans_opt ::=",
 /*  11 */ "trans_opt ::= TRANSACTION",
 /*  12 */ "trans_opt ::= TRANSACTION nm",
 /*  13 */ "transtype ::=",
 /*  14 */ "transtype ::= DEFERRED",
 /*  15 */ "transtype ::= IMMEDIATE",
 /*  16 */ "transtype ::= EXCLUSIVE",
 /*  17 */ "cmd ::= COMMIT trans_opt",
 /*  18 */ "cmd ::= END trans_opt",
 /*  19 */ "cmd ::= ROLLBACK trans_opt",
 /*  20 */ "savepoint_opt ::= SAVEPOINT",
 /*  21 */ "savepoint_opt ::=",
 /*  22 */ "cmd ::= SAVEPOINT nm",
 /*  23 */ "cmd ::= RELEASE savepoint_opt nm",
 /*  24 */ "cmd ::= ROLLBACK trans_opt TO savepoint_opt nm",
 /*  25 */ "cmd ::= create_table create_table_args",
 /*  26 */ "create_table ::= createkw temp TABLE ifnotexists nm dbnm",
 /*  27 */ "createkw ::= CREATE",
 /*  28 */ "ifnotexists ::=",
 /*  29 */ "ifnotexists ::= IF NOT EXISTS",
 /*  30 */ "temp ::= TEMP",
 /*  31 */ "temp ::=",
 /*  32 */ "create_table_args ::= LP columnlist conslist_opt RP",
 /*  33 */ "create_table_args ::= AS select",
 /*  34 */ "columnlist ::= columnlist COMMA column",
 /*  35 */ "columnlist ::= column",
 /*  36 */ "column ::= columnid type carglist",
 /*  37 */ "columnid ::= nm",
 /*  38 */ "id ::= ID",
 /*  39 */ "id ::= INDEXED",
 /*  40 */ "ids ::= ID|STRING",
 /*  41 */ "nm ::= id",
 /*  42 */ "nm ::= STRING",
 /*  43 */ "nm ::= JOIN_KW",
 /*  44 */ "type ::=",
 /*  45 */ "type ::= typetoken",
 /*  46 */ "typetoken ::= typename",
 /*  47 */ "typetoken ::= typename LP signed RP",
 /*  48 */ "typetoken ::= typename LP signed COMMA signed RP",
 /*  49 */ "typename ::= ids",
 /*  50 */ "typename ::= typename ids",
 /*  51 */ "signed ::= plus_num",
 /*  52 */ "signed ::= minus_num",
 /*  53 */ "carglist ::= carglist carg",
 /*  54 */ "carglist ::=",
 /*  55 */ "carg ::= CONSTRAINT nm ccons",
 /*  56 */ "carg ::= ccons",
 /*  57 */ "ccons ::= DEFAULT term",
 /*  58 */ "ccons ::= DEFAULT LP expr RP",
 /*  59 */ "ccons ::= DEFAULT PLUS term",
 /*  60 */ "ccons ::= DEFAULT MINUS term",
 /*  61 */ "ccons ::= DEFAULT id",
 /*  62 */ "ccons ::= NULL onconf",
 /*  63 */ "ccons ::= NOT NULL onconf",
 /*  64 */ "ccons ::= PRIMARY KEY sortorder onconf autoinc",
 /*  65 */ "ccons ::= UNIQUE onconf",
 /*  66 */ "ccons ::= CHECK LP expr RP",
 /*  67 */ "ccons ::= REFERENCES nm idxlist_opt refargs",
 /*  68 */ "ccons ::= defer_subclause",
 /*  69 */ "ccons ::= COLLATE ids",
 /*  70 */ "autoinc ::=",
 /*  71 */ "autoinc ::= AUTOINCR",
 /*  72 */ "refargs ::=",
 /*  73 */ "refargs ::= refargs refarg",
 /*  74 */ "refarg ::= MATCH nm",
 /*  75 */ "refarg ::= ON DELETE refact",
 /*  76 */ "refarg ::= ON UPDATE refact",
 /*  77 */ "refarg ::= ON INSERT refact",
 /*  78 */ "refact ::= SET NULL",
 /*  79 */ "refact ::= SET DEFAULT",
 /*  80 */ "refact ::= CASCADE",
 /*  81 */ "refact ::= RESTRICT",
 /*  82 */ "defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt",
 /*  83 */ "defer_subclause ::= DEFERRABLE init_deferred_pred_opt",
 /*  84 */ "init_deferred_pred_opt ::=",
 /*  85 */ "init_deferred_pred_opt ::= INITIALLY DEFERRED",
 /*  86 */ "init_deferred_pred_opt ::= INITIALLY IMMEDIATE",
 /*  87 */ "conslist_opt ::=",
 /*  88 */ "conslist_opt ::= COMMA conslist",
 /*  89 */ "conslist ::= conslist COMMA tcons",
 /*  90 */ "conslist ::= conslist tcons",
 /*  91 */ "conslist ::= tcons",
 /*  92 */ "tcons ::= CONSTRAINT nm",
 /*  93 */ "tcons ::= PRIMARY KEY LP idxlist autoinc RP onconf",
 /*  94 */ "tcons ::= UNIQUE LP idxlist RP onconf",
 /*  95 */ "tcons ::= CHECK LP expr RP onconf",
 /*  96 */ "tcons ::= FOREIGN KEY LP idxlist RP REFERENCES nm idxlist_opt refargs defer_subclause_opt",
 /*  97 */ "defer_subclause_opt ::=",
 /*  98 */ "defer_subclause_opt ::= defer_subclause",
 /*  99 */ "onconf ::=",
 /* 100 */ "onconf ::= ON CONFLICT resolvetype",
 /* 101 */ "orconf ::=",
 /* 102 */ "orconf ::= OR resolvetype",
 /* 103 */ "resolvetype ::= raisetype",
 /* 104 */ "resolvetype ::= IGNORE",
 /* 105 */ "resolvetype ::= REPLACE",
 /* 106 */ "cmd ::= DROP TABLE ifexists fullname",
 /* 107 */ "ifexists ::= IF EXISTS",
 /* 108 */ "ifexists ::=",
 /* 109 */ "cmd ::= createkw temp VIEW ifnotexists nm dbnm AS select",
 /* 110 */ "cmd ::= DROP VIEW ifexists fullname",
 /* 111 */ "cmd ::= select",
 /* 112 */ "select ::= oneselect",
 /* 113 */ "select ::= select multiselect_op oneselect",
 /* 114 */ "multiselect_op ::= UNION",
 /* 115 */ "multiselect_op ::= UNION ALL",
 /* 116 */ "multiselect_op ::= EXCEPT|INTERSECT",
 /* 117 */ "oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt",
 /* 118 */ "distinct ::= DISTINCT",
 /* 119 */ "distinct ::= ALL",
 /* 120 */ "distinct ::=",
 /* 121 */ "sclp ::= selcollist COMMA",
 /* 122 */ "sclp ::=",
 /* 123 */ "selcollist ::= sclp expr as",
 /* 124 */ "selcollist ::= sclp STAR",
 /* 125 */ "selcollist ::= sclp nm DOT STAR",
 /* 126 */ "as ::= AS nm",
 /* 127 */ "as ::= ids",
 /* 128 */ "as ::=",
 /* 129 */ "from ::=",
 /* 130 */ "from ::= FROM seltablist",
 /* 131 */ "stl_prefix ::= seltablist joinop",
 /* 132 */ "stl_prefix ::=",
 /* 133 */ "seltablist ::= stl_prefix nm dbnm as indexed_opt on_opt using_opt",
 /* 134 */ "seltablist ::= stl_prefix LP select RP as on_opt using_opt",
 /* 135 */ "seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt",
 /* 136 */ "dbnm ::=",
 /* 137 */ "dbnm ::= DOT nm",
 /* 138 */ "fullname ::= nm dbnm",
 /* 139 */ "joinop ::= COMMA|JOIN",
 /* 140 */ "joinop ::= JOIN_KW JOIN",
 /* 141 */ "joinop ::= JOIN_KW nm JOIN",
 /* 142 */ "joinop ::= JOIN_KW nm nm JOIN",
 /* 143 */ "on_opt ::= ON expr",
 /* 144 */ "on_opt ::=",
 /* 145 */ "indexed_opt ::=",
 /* 146 */ "indexed_opt ::= INDEXED BY nm",
 /* 147 */ "indexed_opt ::= NOT INDEXED",
 /* 148 */ "using_opt ::= USING LP inscollist RP",
 /* 149 */ "using_opt ::=",
 /* 150 */ "orderby_opt ::=",
 /* 151 */ "orderby_opt ::= ORDER BY sortlist",
 /* 152 */ "sortlist ::= sortlist COMMA sortitem sortorder",
 /* 153 */ "sortlist ::= sortitem sortorder",
 /* 154 */ "sortitem ::= expr",
 /* 155 */ "sortorder ::= ASC",
 /* 156 */ "sortorder ::= DESC",
 /* 157 */ "sortorder ::=",
 /* 158 */ "groupby_opt ::=",
 /* 159 */ "groupby_opt ::= GROUP BY nexprlist",
 /* 160 */ "having_opt ::=",
 /* 161 */ "having_opt ::= HAVING expr",
 /* 162 */ "limit_opt ::=",
 /* 163 */ "limit_opt ::= LIMIT expr",
 /* 164 */ "limit_opt ::= LIMIT expr OFFSET expr",
 /* 165 */ "limit_opt ::= LIMIT expr COMMA expr",
 /* 166 */ "cmd ::= DELETE FROM fullname indexed_opt where_opt",
 /* 167 */ "where_opt ::=",
 /* 168 */ "where_opt ::= WHERE expr",
 /* 169 */ "cmd ::= UPDATE orconf fullname indexed_opt SET setlist where_opt",
 /* 170 */ "setlist ::= setlist COMMA nm EQ expr",
 /* 171 */ "setlist ::= nm EQ expr",
 /* 172 */ "cmd ::= insert_cmd INTO fullname inscollist_opt VALUES LP itemlist RP",
 /* 173 */ "cmd ::= insert_cmd INTO fullname inscollist_opt select",
 /* 174 */ "cmd ::= insert_cmd INTO fullname inscollist_opt DEFAULT VALUES",
 /* 175 */ "insert_cmd ::= INSERT orconf",
 /* 176 */ "insert_cmd ::= REPLACE",
 /* 177 */ "itemlist ::= itemlist COMMA expr",
 /* 178 */ "itemlist ::= expr",
 /* 179 */ "inscollist_opt ::=",
 /* 180 */ "inscollist_opt ::= LP inscollist RP",
 /* 181 */ "inscollist ::= inscollist COMMA nm",
 /* 182 */ "inscollist ::= nm",
 /* 183 */ "expr ::= term",
 /* 184 */ "expr ::= LP expr RP",
 /* 185 */ "term ::= NULL",
 /* 186 */ "expr ::= id",
 /* 187 */ "expr ::= JOIN_KW",
 /* 188 */ "expr ::= nm DOT nm",
 /* 189 */ "expr ::= nm DOT nm DOT nm",
 /* 190 */ "term ::= INTEGER|FLOAT|BLOB",
 /* 191 */ "term ::= STRING",
 /* 192 */ "expr ::= REGISTER",
 /* 193 */ "expr ::= VARIABLE",
 /* 194 */ "expr ::= expr COLLATE ids",
 /* 195 */ "expr ::= CAST LP expr AS typetoken RP",
 /* 196 */ "expr ::= ID LP distinct exprlist RP",
 /* 197 */ "expr ::= ID LP STAR RP",
 /* 198 */ "term ::= CTIME_KW",
 /* 199 */ "expr ::= expr AND expr",
 /* 200 */ "expr ::= expr OR expr",
 /* 201 */ "expr ::= expr LT|GT|GE|LE expr",
 /* 202 */ "expr ::= expr EQ|NE expr",
 /* 203 */ "expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr",
 /* 204 */ "expr ::= expr PLUS|MINUS expr",
 /* 205 */ "expr ::= expr STAR|SLASH|REM expr",
 /* 206 */ "expr ::= expr CONCAT expr",
 /* 207 */ "likeop ::= LIKE_KW",
 /* 208 */ "likeop ::= NOT LIKE_KW",
 /* 209 */ "likeop ::= MATCH",
 /* 210 */ "likeop ::= NOT MATCH",
 /* 211 */ "escape ::= ESCAPE expr",
 /* 212 */ "escape ::=",
 /* 213 */ "expr ::= expr likeop expr escape",
 /* 214 */ "expr ::= expr ISNULL|NOTNULL",
 /* 215 */ "expr ::= expr IS NULL",
 /* 216 */ "expr ::= expr NOT NULL",
 /* 217 */ "expr ::= expr IS NOT NULL",
 /* 218 */ "expr ::= NOT expr",
 /* 219 */ "expr ::= BITNOT expr",
 /* 220 */ "expr ::= MINUS expr",
 /* 221 */ "expr ::= PLUS expr",
 /* 222 */ "between_op ::= BETWEEN",
 /* 223 */ "between_op ::= NOT BETWEEN",
 /* 224 */ "expr ::= expr between_op expr AND expr",
 /* 225 */ "in_op ::= IN",
 /* 226 */ "in_op ::= NOT IN",
 /* 227 */ "expr ::= expr in_op LP exprlist RP",
 /* 228 */ "expr ::= LP select RP",
 /* 229 */ "expr ::= expr in_op LP select RP",
 /* 230 */ "expr ::= expr in_op nm dbnm",
 /* 231 */ "expr ::= EXISTS LP select RP",
 /* 232 */ "expr ::= CASE case_operand case_exprlist case_else END",
 /* 233 */ "case_exprlist ::= case_exprlist WHEN expr THEN expr",
 /* 234 */ "case_exprlist ::= WHEN expr THEN expr",
 /* 235 */ "case_else ::= ELSE expr",
 /* 236 */ "case_else ::=",
 /* 237 */ "case_operand ::= expr",
 /* 238 */ "case_operand ::=",
 /* 239 */ "exprlist ::= nexprlist",
 /* 240 */ "exprlist ::=",
 /* 241 */ "nexprlist ::= nexprlist COMMA expr",
 /* 242 */ "nexprlist ::= expr",
 /* 243 */ "cmd ::= createkw uniqueflag INDEX ifnotexists nm dbnm ON nm LP idxlist RP",
 /* 244 */ "uniqueflag ::= UNIQUE",
 /* 245 */ "uniqueflag ::=",
 /* 246 */ "idxlist_opt ::=",
 /* 247 */ "idxlist_opt ::= LP idxlist RP",
 /* 248 */ "idxlist ::= idxlist COMMA nm collate sortorder",
 /* 249 */ "idxlist ::= nm collate sortorder",
 /* 250 */ "collate ::=",
 /* 251 */ "collate ::= COLLATE ids",
 /* 252 */ "cmd ::= DROP INDEX ifexists fullname",
 /* 253 */ "cmd ::= VACUUM",
 /* 254 */ "cmd ::= VACUUM nm",
 /* 255 */ "cmd ::= PRAGMA nm dbnm",
 /* 256 */ "cmd ::= PRAGMA nm dbnm EQ nmnum",
 /* 257 */ "cmd ::= PRAGMA nm dbnm LP nmnum RP",
 /* 258 */ "cmd ::= PRAGMA nm dbnm EQ minus_num",
 /* 259 */ "cmd ::= PRAGMA nm dbnm LP minus_num RP",
 /* 260 */ "nmnum ::= plus_num",
 /* 261 */ "nmnum ::= nm",
 /* 262 */ "nmnum ::= ON",
 /* 263 */ "nmnum ::= DELETE",
 /* 264 */ "nmnum ::= DEFAULT",
 /* 265 */ "plus_num ::= plus_opt number",
 /* 266 */ "minus_num ::= MINUS number",
 /* 267 */ "number ::= INTEGER|FLOAT",
 /* 268 */ "plus_opt ::= PLUS",
 /* 269 */ "plus_opt ::=",
 /* 270 */ "cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END",
 /* 271 */ "trigger_decl ::= temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON fullname foreach_clause when_clause",
 /* 272 */ "trigger_time ::= BEFORE",
 /* 273 */ "trigger_time ::= AFTER",
 /* 274 */ "trigger_time ::= INSTEAD OF",
 /* 275 */ "trigger_time ::=",
 /* 276 */ "trigger_event ::= DELETE|INSERT",
 /* 277 */ "trigger_event ::= UPDATE",
 /* 278 */ "trigger_event ::= UPDATE OF inscollist",
 /* 279 */ "foreach_clause ::=",
 /* 280 */ "foreach_clause ::= FOR EACH ROW",
 /* 281 */ "when_clause ::=",
 /* 282 */ "when_clause ::= WHEN expr",
 /* 283 */ "trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI",
 /* 284 */ "trigger_cmd_list ::= trigger_cmd SEMI",
 /* 285 */ "trigger_cmd ::= UPDATE orconf nm SET setlist where_opt",
 /* 286 */ "trigger_cmd ::= insert_cmd INTO nm inscollist_opt VALUES LP itemlist RP",
 /* 287 */ "trigger_cmd ::= insert_cmd INTO nm inscollist_opt select",
 /* 288 */ "trigger_cmd ::= DELETE FROM nm where_opt",
 /* 289 */ "trigger_cmd ::= select",
 /* 290 */ "expr ::= RAISE LP IGNORE RP",
 /* 291 */ "expr ::= RAISE LP raisetype COMMA nm RP",
 /* 292 */ "raisetype ::= ROLLBACK",
 /* 293 */ "raisetype ::= ABORT",
 /* 294 */ "raisetype ::= FAIL",
 /* 295 */ "cmd ::= DROP TRIGGER ifexists fullname",
 /* 296 */ "cmd ::= ATTACH database_kw_opt expr AS expr key_opt",
 /* 297 */ "cmd ::= DETACH database_kw_opt expr",
 /* 298 */ "key_opt ::=",
 /* 299 */ "key_opt ::= KEY expr",
 /* 300 */ "database_kw_opt ::= DATABASE",
 /* 301 */ "database_kw_opt ::=",
 /* 302 */ "cmd ::= REINDEX",
 /* 303 */ "cmd ::= REINDEX nm dbnm",
 /* 304 */ "cmd ::= ANALYZE",
 /* 305 */ "cmd ::= ANALYZE nm dbnm",
 /* 306 */ "cmd ::= ALTER TABLE fullname RENAME TO nm",
 /* 307 */ "cmd ::= ALTER TABLE add_column_fullname ADD kwcolumn_opt column",
 /* 308 */ "add_column_fullname ::= fullname",
 /* 309 */ "kwcolumn_opt ::=",
 /* 310 */ "kwcolumn_opt ::= COLUMNKW",
 /* 311 */ "cmd ::= create_vtab",
 /* 312 */ "cmd ::= create_vtab LP vtabarglist RP",
 /* 313 */ "create_vtab ::= createkw VIRTUAL TABLE nm dbnm USING nm",
 /* 314 */ "vtabarglist ::= vtabarg",
 /* 315 */ "vtabarglist ::= vtabarglist COMMA vtabarg",
 /* 316 */ "vtabarg ::=",
 /* 317 */ "vtabarg ::= vtabarg vtabargtoken",
 /* 318 */ "vtabargtoken ::= ANY",
 /* 319 */ "vtabargtoken ::= lp anylist RP",
 /* 320 */ "lp ::= LP",
 /* 321 */ "anylist ::=",
 /* 322 */ "anylist ::= anylist ANY",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.
*/
static void yyGrowStack(yyParser *p){
  int newSize;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  if( pNew ){
    p->yystack = pNew;
    p->yystksz = newSize;
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows to %d entries!\n",
              yyTracePrompt, p->yystksz);
    }
#endif
  }
}
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to sqlite3Parser and sqlite3ParserFree.
*/
void *sqlite3ParserAlloc(void *(*mallocProc)(size_t)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (size_t)sizeof(yyParser) );
  if( pParser ){
    pParser->yyidx = -1;
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyidxMax = 0;
#endif
#if YYSTACKDEPTH<=0
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    yyGrowStack(pParser);
#endif
  }
  return pParser;
}

/* The following function deletes the value associated with a
** symbol.  The symbol can be either a terminal or nonterminal.
** "yymajor" is the symbol code, and "yypminor" is a pointer to
** the value.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  sqlite3ParserARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are not used
    ** inside the C code.
    */
    case 160: /* select */
    case 194: /* oneselect */
{
#line 391 "parse.y"
sqlite3SelectDelete(pParse->db, (yypminor->yy243));
#line 1339 "parse.c"
}
      break;
    case 174: /* term */
    case 175: /* expr */
    case 199: /* where_opt */
    case 201: /* having_opt */
    case 210: /* on_opt */
    case 215: /* sortitem */
    case 223: /* escape */
    case 226: /* case_operand */
    case 228: /* case_else */
    case 239: /* when_clause */
    case 242: /* key_opt */
{
#line 702 "parse.y"
sqlite3ExprDelete(pParse->db, (yypminor->yy72));
#line 1356 "parse.c"
}
      break;
    case 179: /* idxlist_opt */
    case 187: /* idxlist */
    case 197: /* selcollist */
    case 200: /* groupby_opt */
    case 202: /* orderby_opt */
    case 204: /* sclp */
    case 214: /* sortlist */
    case 216: /* nexprlist */
    case 217: /* setlist */
    case 220: /* itemlist */
    case 221: /* exprlist */
    case 227: /* case_exprlist */
{
#line 964 "parse.y"
sqlite3ExprListDelete(pParse->db, (yypminor->yy148));
#line 1374 "parse.c"
}
      break;
    case 193: /* fullname */
    case 198: /* from */
    case 206: /* seltablist */
    case 207: /* stl_prefix */
{
#line 520 "parse.y"
sqlite3SrcListDelete(pParse->db, (yypminor->yy185));
#line 1384 "parse.c"
}
      break;
    case 211: /* using_opt */
    case 213: /* inscollist */
    case 219: /* inscollist_opt */
{
#line 552 "parse.y"
sqlite3IdListDelete(pParse->db, (yypminor->yy254));
#line 1393 "parse.c"
}
      break;
    case 235: /* trigger_cmd_list */
    case 240: /* trigger_cmd */
{
#line 1071 "parse.y"
sqlite3DeleteTriggerStep(pParse->db, (yypminor->yy145));
#line 1401 "parse.c"
}
      break;
    case 237: /* trigger_event */
{
#line 1057 "parse.y"
sqlite3IdListDelete(pParse->db, (yypminor->yy332).b);
#line 1408 "parse.c"
}
      break;
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
**
** Return the major token number for the symbol popped.
*/
static int yy_pop_parser_stack(yyParser *pParser){
  YYCODETYPE yymajor;
  yyStackEntry *yytos = &pParser->yystack[pParser->yyidx];

  if( pParser->yyidx<0 ) return 0;
#ifndef NDEBUG
  if( yyTraceFILE && pParser->yyidx>=0 ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yymajor = yytos->major;
  yy_destructor(pParser, yymajor, &yytos->minor);
  pParser->yyidx--;
  return yymajor;
}

/* 
** Deallocate and destroy a parser.  Destructors are all called for
** all stack elements before shutting the parser down.
**
** Inputs:
** <ul>
** <li>  A pointer to the parser.  This should be a pointer
**       obtained from sqlite3ParserAlloc.
** <li>  A pointer to a function used to reclaim memory obtained
**       from malloc.
** </ul>
*/
void sqlite3ParserFree(
  void *p,                    /* The parser to be deleted */
  void (*freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
  if( pParser==0 ) return;
  while( pParser->yyidx>=0 ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int sqlite3ParserStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyidxMax;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
**
** If the look-ahead token is YYNOCODE, then check to see if the action is
** independent of the look-ahead.  If it is, return the action, otherwise
** return YY_NO_ACTION.
*/
static int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yystack[pParser->yyidx].stateno;
 
  if( stateno>YY_SHIFT_MAX || (i = yy_shift_ofst[stateno])==YY_SHIFT_USE_DFLT ){
    return yy_default[stateno];
  }
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
  if( i<0 || i>=YY_SZ_ACTTAB || yy_lookahead[i]!=iLookAhead ){
    if( iLookAhead>0 ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        return yy_find_shift_action(pParser, iFallback);
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( j>=0 && j<YY_SZ_ACTTAB && yy_lookahead[j]==YYWILDCARD ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
    }
    return yy_default[stateno];
  }else{
    return yy_action[i];
  }
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
**
** If the look-ahead token is YYNOCODE, then check to see if the action is
** independent of the look-ahead.  If it is, return the action, otherwise
** return YY_NO_ACTION.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_MAX ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_MAX );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_SZ_ACTTAB || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_SZ_ACTTAB );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser, YYMINORTYPE *yypMinor){
   sqlite3ParserARG_FETCH;
   yypParser->yyidx--;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
#line 40 "parse.y"

  UNUSED_PARAMETER(yypMinor); /* Silence some compiler warnings */
  sqlite3ErrorMsg(pParse, "parser stack overflow");
  pParse->parseError = 1;
#line 1586 "parse.c"
   sqlite3ParserARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  YYMINORTYPE *yypMinor         /* Pointer to the minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yyidx++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( yypParser->yyidx>yypParser->yyidxMax ){
    yypParser->yyidxMax = yypParser->yyidx;
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yyidx>=YYSTACKDEPTH ){
    yyStackOverflow(yypParser, yypMinor);
    return;
  }
#else
  if( yypParser->yyidx>=yypParser->yystksz ){
    yyGrowStack(yypParser);
    if( yypParser->yyidx>=yypParser->yystksz ){
      yyStackOverflow(yypParser, yypMinor);
      return;
    }
  }
#endif
  yytos = &yypParser->yystack[yypParser->yyidx];
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor = *yypMinor;
#ifndef NDEBUG
  if( yyTraceFILE && yypParser->yyidx>0 ){
    int i;
    fprintf(yyTraceFILE,"%sShift %d\n",yyTracePrompt,yyNewState);
    fprintf(yyTraceFILE,"%sStack:",yyTracePrompt);
    for(i=1; i<=yypParser->yyidx; i++)
      fprintf(yyTraceFILE," %s",yyTokenName[yypParser->yystack[i].major]);
    fprintf(yyTraceFILE,"\n");
  }
#endif
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 142, 1 },
  { 143, 2 },
  { 143, 1 },
  { 144, 1 },
  { 144, 3 },
  { 145, 0 },
  { 145, 1 },
  { 145, 3 },
  { 146, 1 },
  { 147, 3 },
  { 149, 0 },
  { 149, 1 },
  { 149, 2 },
  { 148, 0 },
  { 148, 1 },
  { 148, 1 },
  { 148, 1 },
  { 147, 2 },
  { 147, 2 },
  { 147, 2 },
  { 151, 1 },
  { 151, 0 },
  { 147, 2 },
  { 147, 3 },
  { 147, 5 },
  { 147, 2 },
  { 152, 6 },
  { 154, 1 },
  { 156, 0 },
  { 156, 3 },
  { 155, 1 },
  { 155, 0 },
  { 153, 4 },
  { 153, 2 },
  { 158, 3 },
  { 158, 1 },
  { 161, 3 },
  { 162, 1 },
  { 165, 1 },
  { 165, 1 },
  { 166, 1 },
  { 150, 1 },
  { 150, 1 },
  { 150, 1 },
  { 163, 0 },
  { 163, 1 },
  { 167, 1 },
  { 167, 4 },
  { 167, 6 },
  { 168, 1 },
  { 168, 2 },
  { 169, 1 },
  { 169, 1 },
  { 164, 2 },
  { 164, 0 },
  { 172, 3 },
  { 172, 1 },
  { 173, 2 },
  { 173, 4 },
  { 173, 3 },
  { 173, 3 },
  { 173, 2 },
  { 173, 2 },
  { 173, 3 },
  { 173, 5 },
  { 173, 2 },
  { 173, 4 },
  { 173, 4 },
  { 173, 1 },
  { 173, 2 },
  { 178, 0 },
  { 178, 1 },
  { 180, 0 },
  { 180, 2 },
  { 182, 2 },
  { 182, 3 },
  { 182, 3 },
  { 182, 3 },
  { 183, 2 },
  { 183, 2 },
  { 183, 1 },
  { 183, 1 },
  { 181, 3 },
  { 181, 2 },
  { 184, 0 },
  { 184, 2 },
  { 184, 2 },
  { 159, 0 },
  { 159, 2 },
  { 185, 3 },
  { 185, 2 },
  { 185, 1 },
  { 186, 2 },
  { 186, 7 },
  { 186, 5 },
  { 186, 5 },
  { 186, 10 },
  { 188, 0 },
  { 188, 1 },
  { 176, 0 },
  { 176, 3 },
  { 189, 0 },
  { 189, 2 },
  { 190, 1 },
  { 190, 1 },
  { 190, 1 },
  { 147, 4 },
  { 192, 2 },
  { 192, 0 },
  { 147, 8 },
  { 147, 4 },
  { 147, 1 },
  { 160, 1 },
  { 160, 3 },
  { 195, 1 },
  { 195, 2 },
  { 195, 1 },
  { 194, 9 },
  { 196, 1 },
  { 196, 1 },
  { 196, 0 },
  { 204, 2 },
  { 204, 0 },
  { 197, 3 },
  { 197, 2 },
  { 197, 4 },
  { 205, 2 },
  { 205, 1 },
  { 205, 0 },
  { 198, 0 },
  { 198, 2 },
  { 207, 2 },
  { 207, 0 },
  { 206, 7 },
  { 206, 7 },
  { 206, 7 },
  { 157, 0 },
  { 157, 2 },
  { 193, 2 },
  { 208, 1 },
  { 208, 2 },
  { 208, 3 },
  { 208, 4 },
  { 210, 2 },
  { 210, 0 },
  { 209, 0 },
  { 209, 3 },
  { 209, 2 },
  { 211, 4 },
  { 211, 0 },
  { 202, 0 },
  { 202, 3 },
  { 214, 4 },
  { 214, 2 },
  { 215, 1 },
  { 177, 1 },
  { 177, 1 },
  { 177, 0 },
  { 200, 0 },
  { 200, 3 },
  { 201, 0 },
  { 201, 2 },
  { 203, 0 },
  { 203, 2 },
  { 203, 4 },
  { 203, 4 },
  { 147, 5 },
  { 199, 0 },
  { 199, 2 },
  { 147, 7 },
  { 217, 5 },
  { 217, 3 },
  { 147, 8 },
  { 147, 5 },
  { 147, 6 },
  { 218, 2 },
  { 218, 1 },
  { 220, 3 },
  { 220, 1 },
  { 219, 0 },
  { 219, 3 },
  { 213, 3 },
  { 213, 1 },
  { 175, 1 },
  { 175, 3 },
  { 174, 1 },
  { 175, 1 },
  { 175, 1 },
  { 175, 3 },
  { 175, 5 },
  { 174, 1 },
  { 174, 1 },
  { 175, 1 },
  { 175, 1 },
  { 175, 3 },
  { 175, 6 },
  { 175, 5 },
  { 175, 4 },
  { 174, 1 },
  { 175, 3 },
  { 175, 3 },
  { 175, 3 },
  { 175, 3 },
  { 175, 3 },
  { 175, 3 },
  { 175, 3 },
  { 175, 3 },
  { 222, 1 },
  { 222, 2 },
  { 222, 1 },
  { 222, 2 },
  { 223, 2 },
  { 223, 0 },
  { 175, 4 },
  { 175, 2 },
  { 175, 3 },
  { 175, 3 },
  { 175, 4 },
  { 175, 2 },
  { 175, 2 },
  { 175, 2 },
  { 175, 2 },
  { 224, 1 },
  { 224, 2 },
  { 175, 5 },
  { 225, 1 },
  { 225, 2 },
  { 175, 5 },
  { 175, 3 },
  { 175, 5 },
  { 175, 4 },
  { 175, 4 },
  { 175, 5 },
  { 227, 5 },
  { 227, 4 },
  { 228, 2 },
  { 228, 0 },
  { 226, 1 },
  { 226, 0 },
  { 221, 1 },
  { 221, 0 },
  { 216, 3 },
  { 216, 1 },
  { 147, 11 },
  { 229, 1 },
  { 229, 0 },
  { 179, 0 },
  { 179, 3 },
  { 187, 5 },
  { 187, 3 },
  { 230, 0 },
  { 230, 2 },
  { 147, 4 },
  { 147, 1 },
  { 147, 2 },
  { 147, 3 },
  { 147, 5 },
  { 147, 6 },
  { 147, 5 },
  { 147, 6 },
  { 231, 1 },
  { 231, 1 },
  { 231, 1 },
  { 231, 1 },
  { 231, 1 },
  { 170, 2 },
  { 171, 2 },
  { 233, 1 },
  { 232, 1 },
  { 232, 0 },
  { 147, 5 },
  { 234, 11 },
  { 236, 1 },
  { 236, 1 },
  { 236, 2 },
  { 236, 0 },
  { 237, 1 },
  { 237, 1 },
  { 237, 3 },
  { 238, 0 },
  { 238, 3 },
  { 239, 0 },
  { 239, 2 },
  { 235, 3 },
  { 235, 2 },
  { 240, 6 },
  { 240, 8 },
  { 240, 5 },
  { 240, 4 },
  { 240, 1 },
  { 175, 4 },
  { 175, 6 },
  { 191, 1 },
  { 191, 1 },
  { 191, 1 },
  { 147, 4 },
  { 147, 6 },
  { 147, 3 },
  { 242, 0 },
  { 242, 2 },
  { 241, 1 },
  { 241, 0 },
  { 147, 1 },
  { 147, 3 },
  { 147, 1 },
  { 147, 3 },
  { 147, 6 },
  { 147, 6 },
  { 243, 1 },
  { 244, 0 },
  { 244, 1 },
  { 147, 1 },
  { 147, 4 },
  { 245, 7 },
  { 246, 1 },
  { 246, 3 },
  { 247, 0 },
  { 247, 2 },
  { 248, 1 },
  { 248, 3 },
  { 249, 1 },
  { 250, 0 },
  { 250, 2 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  int yyruleno                 /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  YYMINORTYPE yygotominor;        /* The LHS of the rule reduced */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  sqlite3ParserARG_FETCH;
  yymsp = &yypParser->yystack[yypParser->yyidx];
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno>=0 
        && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    fprintf(yyTraceFILE, "%sReduce [%s].\n", yyTracePrompt,
      yyRuleName[yyruleno]);
  }
#endif /* NDEBUG */

  /* Silence complaints from purify about yygotominor being uninitialized
  ** in some cases when it is copied into the stack after the following
  ** switch.  yygotominor is uninitialized when a rule reduces that does
  ** not set the value of its left-hand side nonterminal.  Leaving the
  ** value of the nonterminal uninitialized is utterly harmless as long
  ** as the value is never used.  So really the only thing this code
  ** accomplishes is to quieten purify.  
  **
  ** 2007-01-16:  The wireshark project (www.wireshark.org) reports that
  ** without this code, their parser segfaults.  I'm not sure what there
  ** parser is doing to make this happen.  This is the second bug report
  ** from wireshark this week.  Clearly they are stressing Lemon in ways
  ** that it has not been previously stressed...  (SQLite ticket #2172)
  */
  /*memset(&yygotominor, 0, sizeof(yygotominor));*/
  yygotominor = yyzerominor;


  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
      case 0: /* input ::= cmdlist */
      case 1: /* cmdlist ::= cmdlist ecmd */
      case 2: /* cmdlist ::= ecmd */
      case 3: /* ecmd ::= SEMI */
      case 4: /* ecmd ::= explain cmdx SEMI */
      case 10: /* trans_opt ::= */
      case 11: /* trans_opt ::= TRANSACTION */
      case 12: /* trans_opt ::= TRANSACTION nm */
      case 20: /* savepoint_opt ::= SAVEPOINT */
      case 21: /* savepoint_opt ::= */
      case 25: /* cmd ::= create_table create_table_args */
      case 34: /* columnlist ::= columnlist COMMA column */
      case 35: /* columnlist ::= column */
      case 44: /* type ::= */
      case 51: /* signed ::= plus_num */
      case 52: /* signed ::= minus_num */
      case 53: /* carglist ::= carglist carg */
      case 54: /* carglist ::= */
      case 55: /* carg ::= CONSTRAINT nm ccons */
      case 56: /* carg ::= ccons */
      case 62: /* ccons ::= NULL onconf */
      case 89: /* conslist ::= conslist COMMA tcons */
      case 90: /* conslist ::= conslist tcons */
      case 91: /* conslist ::= tcons */
      case 92: /* tcons ::= CONSTRAINT nm */
      case 268: /* plus_opt ::= PLUS */
      case 269: /* plus_opt ::= */
      case 279: /* foreach_clause ::= */
      case 280: /* foreach_clause ::= FOR EACH ROW */
      case 300: /* database_kw_opt ::= DATABASE */
      case 301: /* database_kw_opt ::= */
      case 309: /* kwcolumn_opt ::= */
      case 310: /* kwcolumn_opt ::= COLUMNKW */
      case 314: /* vtabarglist ::= vtabarg */
      case 315: /* vtabarglist ::= vtabarglist COMMA vtabarg */
      case 317: /* vtabarg ::= vtabarg vtabargtoken */
      case 321: /* anylist ::= */
#line 93 "parse.y"
{
}
#line 2060 "parse.c"
        break;
      case 5: /* explain ::= */
#line 98 "parse.y"
{ sqlite3BeginParse(pParse, 0); }
#line 2065 "parse.c"
        break;
      case 6: /* explain ::= EXPLAIN */
#line 100 "parse.y"
{ sqlite3BeginParse(pParse, 1); }
#line 2070 "parse.c"
        break;
      case 7: /* explain ::= EXPLAIN QUERY PLAN */
#line 101 "parse.y"
{ sqlite3BeginParse(pParse, 2); }
#line 2075 "parse.c"
        break;
      case 8: /* cmdx ::= cmd */
#line 103 "parse.y"
{ sqlite3FinishCoding(pParse); }
#line 2080 "parse.c"
        break;
      case 9: /* cmd ::= BEGIN transtype trans_opt */
#line 108 "parse.y"
{sqlite3BeginTransaction(pParse, yymsp[-1].minor.yy194);}
#line 2085 "parse.c"
        break;
      case 13: /* transtype ::= */
#line 113 "parse.y"
{yygotominor.yy194 = TK_DEFERRED;}
#line 2090 "parse.c"
        break;
      case 14: /* transtype ::= DEFERRED */
      case 15: /* transtype ::= IMMEDIATE */
      case 16: /* transtype ::= EXCLUSIVE */
      case 114: /* multiselect_op ::= UNION */
      case 116: /* multiselect_op ::= EXCEPT|INTERSECT */
#line 114 "parse.y"
{yygotominor.yy194 = yymsp[0].major;}
#line 2099 "parse.c"
        break;
      case 17: /* cmd ::= COMMIT trans_opt */
      case 18: /* cmd ::= END trans_opt */
#line 117 "parse.y"
{sqlite3CommitTransaction(pParse);}
#line 2105 "parse.c"
        break;
      case 19: /* cmd ::= ROLLBACK trans_opt */
#line 119 "parse.y"
{sqlite3RollbackTransaction(pParse);}
#line 2110 "parse.c"
        break;
      case 22: /* cmd ::= SAVEPOINT nm */
#line 123 "parse.y"
{
  sqlite3Savepoint(pParse, SAVEPOINT_BEGIN, &yymsp[0].minor.yy0);
}
#line 2117 "parse.c"
        break;
      case 23: /* cmd ::= RELEASE savepoint_opt nm */
#line 126 "parse.y"
{
  sqlite3Savepoint(pParse, SAVEPOINT_RELEASE, &yymsp[0].minor.yy0);
}
#line 2124 "parse.c"
        break;
      case 24: /* cmd ::= ROLLBACK trans_opt TO savepoint_opt nm */
#line 129 "parse.y"
{
  sqlite3Savepoint(pParse, SAVEPOINT_ROLLBACK, &yymsp[0].minor.yy0);
}
#line 2131 "parse.c"
        break;
      case 26: /* create_table ::= createkw temp TABLE ifnotexists nm dbnm */
#line 136 "parse.y"
{
   sqlite3StartTable(pParse,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy0,yymsp[-4].minor.yy194,0,0,yymsp[-2].minor.yy194);
}
#line 2138 "parse.c"
        break;
      case 27: /* createkw ::= CREATE */
#line 139 "parse.y"
{
  pParse->db->lookaside.bEnabled = 0;
  yygotominor.yy0 = yymsp[0].minor.yy0;
}
#line 2146 "parse.c"
        break;
      case 28: /* ifnotexists ::= */
      case 31: /* temp ::= */
      case 70: /* autoinc ::= */
      case 84: /* init_deferred_pred_opt ::= */
      case 86: /* init_deferred_pred_opt ::= INITIALLY IMMEDIATE */
      case 97: /* defer_subclause_opt ::= */
      case 108: /* ifexists ::= */
      case 119: /* distinct ::= ALL */
      case 120: /* distinct ::= */
      case 222: /* between_op ::= BETWEEN */
      case 225: /* in_op ::= IN */
#line 144 "parse.y"
{yygotominor.yy194 = 0;}
#line 2161 "parse.c"
        break;
      case 29: /* ifnotexists ::= IF NOT EXISTS */
      case 30: /* temp ::= TEMP */
      case 71: /* autoinc ::= AUTOINCR */
      case 85: /* init_deferred_pred_opt ::= INITIALLY DEFERRED */
      case 107: /* ifexists ::= IF EXISTS */
      case 118: /* distinct ::= DISTINCT */
      case 223: /* between_op ::= NOT BETWEEN */
      case 226: /* in_op ::= NOT IN */
#line 145 "parse.y"
{yygotominor.yy194 = 1;}
#line 2173 "parse.c"
        break;
      case 32: /* create_table_args ::= LP columnlist conslist_opt RP */
#line 151 "parse.y"
{
  sqlite3EndTable(pParse,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy0,0);
}
#line 2180 "parse.c"
        break;
      case 33: /* create_table_args ::= AS select */
#line 154 "parse.y"
{
  sqlite3EndTable(pParse,0,0,yymsp[0].minor.yy243);
  sqlite3SelectDelete(pParse->db, yymsp[0].minor.yy243);
}
#line 2188 "parse.c"
        break;
      case 36: /* column ::= columnid type carglist */
#line 166 "parse.y"
{
  yygotominor.yy0.z = yymsp[-2].minor.yy0.z;
  yygotominor.yy0.n = (int)(pParse->sLastToken.z-yymsp[-2].minor.yy0.z) + pParse->sLastToken.n;
  yygotominor.yy0.quoted = 0;
  yygotominor.yy0.dyn = 0;
}
#line 2198 "parse.c"
        break;
      case 37: /* columnid ::= nm */
#line 172 "parse.y"
{
  sqlite3AddColumn(pParse,&yymsp[0].minor.yy0);
  yygotominor.yy0 = yymsp[0].minor.yy0;
}
#line 2206 "parse.c"
        break;
      case 38: /* id ::= ID */
      case 39: /* id ::= INDEXED */
      case 40: /* ids ::= ID|STRING */
      case 41: /* nm ::= id */
      case 42: /* nm ::= STRING */
      case 43: /* nm ::= JOIN_KW */
      case 46: /* typetoken ::= typename */
      case 49: /* typename ::= ids */
      case 126: /* as ::= AS nm */
      case 127: /* as ::= ids */
      case 137: /* dbnm ::= DOT nm */
      case 146: /* indexed_opt ::= INDEXED BY nm */
      case 251: /* collate ::= COLLATE ids */
      case 260: /* nmnum ::= plus_num */
      case 261: /* nmnum ::= nm */
      case 262: /* nmnum ::= ON */
      case 263: /* nmnum ::= DELETE */
      case 264: /* nmnum ::= DEFAULT */
      case 265: /* plus_num ::= plus_opt number */
      case 266: /* minus_num ::= MINUS number */
      case 267: /* number ::= INTEGER|FLOAT */
#line 182 "parse.y"
{yygotominor.yy0 = yymsp[0].minor.yy0;}
#line 2231 "parse.c"
        break;
      case 45: /* type ::= typetoken */
#line 244 "parse.y"
{sqlite3AddColumnType(pParse,&yymsp[0].minor.yy0);}
#line 2236 "parse.c"
        break;
      case 47: /* typetoken ::= typename LP signed RP */
#line 246 "parse.y"
{
  yygotominor.yy0.z = yymsp[-3].minor.yy0.z;
  yygotominor.yy0.n = (int)(&yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n] - yymsp[-3].minor.yy0.z);
}
#line 2244 "parse.c"
        break;
      case 48: /* typetoken ::= typename LP signed COMMA signed RP */
#line 250 "parse.y"
{
  yygotominor.yy0.z = yymsp[-5].minor.yy0.z;
  yygotominor.yy0.n = (int)(&yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n] - yymsp[-5].minor.yy0.z);
}
#line 2252 "parse.c"
        break;
      case 50: /* typename ::= typename ids */
#line 256 "parse.y"
{yygotominor.yy0.z=yymsp[-1].minor.yy0.z; yygotominor.yy0.n=yymsp[0].minor.yy0.n+(int)(yymsp[0].minor.yy0.z-yymsp[-1].minor.yy0.z);}
#line 2257 "parse.c"
        break;
      case 57: /* ccons ::= DEFAULT term */
      case 59: /* ccons ::= DEFAULT PLUS term */
#line 267 "parse.y"
{sqlite3AddDefaultValue(pParse,yymsp[0].minor.yy72);}
#line 2263 "parse.c"
        break;
      case 58: /* ccons ::= DEFAULT LP expr RP */
#line 268 "parse.y"
{sqlite3AddDefaultValue(pParse,yymsp[-1].minor.yy72);}
#line 2268 "parse.c"
        break;
      case 60: /* ccons ::= DEFAULT MINUS term */
#line 270 "parse.y"
{
  Expr *p = sqlite3PExpr(pParse, TK_UMINUS, yymsp[0].minor.yy72, 0, 0);
  sqlite3ExprSpan(p,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy72->span);
  sqlite3AddDefaultValue(pParse,p);
}
#line 2277 "parse.c"
        break;
      case 61: /* ccons ::= DEFAULT id */
#line 275 "parse.y"
{
  Expr *p = sqlite3PExpr(pParse, TK_STRING, 0, 0, &yymsp[0].minor.yy0);
  sqlite3AddDefaultValue(pParse,p);
}
#line 2285 "parse.c"
        break;
      case 63: /* ccons ::= NOT NULL onconf */
#line 284 "parse.y"
{sqlite3AddNotNull(pParse, yymsp[0].minor.yy194);}
#line 2290 "parse.c"
        break;
      case 64: /* ccons ::= PRIMARY KEY sortorder onconf autoinc */
#line 286 "parse.y"
{sqlite3AddPrimaryKey(pParse,0,yymsp[-1].minor.yy194,yymsp[0].minor.yy194,yymsp[-2].minor.yy194);}
#line 2295 "parse.c"
        break;
      case 65: /* ccons ::= UNIQUE onconf */
#line 287 "parse.y"
{sqlite3CreateIndex(pParse,0,0,0,0,yymsp[0].minor.yy194,0,0,0,0);}
#line 2300 "parse.c"
        break;
      case 66: /* ccons ::= CHECK LP expr RP */
#line 288 "parse.y"
{sqlite3AddCheckConstraint(pParse,yymsp[-1].minor.yy72);}
#line 2305 "parse.c"
        break;
      case 67: /* ccons ::= REFERENCES nm idxlist_opt refargs */
#line 290 "parse.y"
{sqlite3CreateForeignKey(pParse,0,&yymsp[-2].minor.yy0,yymsp[-1].minor.yy148,yymsp[0].minor.yy194);}
#line 2310 "parse.c"
        break;
      case 68: /* ccons ::= defer_subclause */
#line 291 "parse.y"
{sqlite3DeferForeignKey(pParse,yymsp[0].minor.yy194);}
#line 2315 "parse.c"
        break;
      case 69: /* ccons ::= COLLATE ids */
#line 292 "parse.y"
{sqlite3AddCollateType(pParse, &yymsp[0].minor.yy0);}
#line 2320 "parse.c"
        break;
      case 72: /* refargs ::= */
#line 305 "parse.y"
{ yygotominor.yy194 = OE_Restrict * 0x010101; }
#line 2325 "parse.c"
        break;
      case 73: /* refargs ::= refargs refarg */
#line 306 "parse.y"
{ yygotominor.yy194 = (yymsp[-1].minor.yy194 & ~yymsp[0].minor.yy497.mask) | yymsp[0].minor.yy497.value; }
#line 2330 "parse.c"
        break;
      case 74: /* refarg ::= MATCH nm */
#line 308 "parse.y"
{ yygotominor.yy497.value = 0;     yygotominor.yy497.mask = 0x000000; }
#line 2335 "parse.c"
        break;
      case 75: /* refarg ::= ON DELETE refact */
#line 309 "parse.y"
{ yygotominor.yy497.value = yymsp[0].minor.yy194;     yygotominor.yy497.mask = 0x0000ff; }
#line 2340 "parse.c"
        break;
      case 76: /* refarg ::= ON UPDATE refact */
#line 310 "parse.y"
{ yygotominor.yy497.value = yymsp[0].minor.yy194<<8;  yygotominor.yy497.mask = 0x00ff00; }
#line 2345 "parse.c"
        break;
      case 77: /* refarg ::= ON INSERT refact */
#line 311 "parse.y"
{ yygotominor.yy497.value = yymsp[0].minor.yy194<<16; yygotominor.yy497.mask = 0xff0000; }
#line 2350 "parse.c"
        break;
      case 78: /* refact ::= SET NULL */
#line 313 "parse.y"
{ yygotominor.yy194 = OE_SetNull; }
#line 2355 "parse.c"
        break;
      case 79: /* refact ::= SET DEFAULT */
#line 314 "parse.y"
{ yygotominor.yy194 = OE_SetDflt; }
#line 2360 "parse.c"
        break;
      case 80: /* refact ::= CASCADE */
#line 315 "parse.y"
{ yygotominor.yy194 = OE_Cascade; }
#line 2365 "parse.c"
        break;
      case 81: /* refact ::= RESTRICT */
#line 316 "parse.y"
{ yygotominor.yy194 = OE_Restrict; }
#line 2370 "parse.c"
        break;
      case 82: /* defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt */
      case 83: /* defer_subclause ::= DEFERRABLE init_deferred_pred_opt */
      case 98: /* defer_subclause_opt ::= defer_subclause */
      case 100: /* onconf ::= ON CONFLICT resolvetype */
      case 102: /* orconf ::= OR resolvetype */
      case 103: /* resolvetype ::= raisetype */
      case 175: /* insert_cmd ::= INSERT orconf */
#line 318 "parse.y"
{yygotominor.yy194 = yymsp[0].minor.yy194;}
#line 2381 "parse.c"
        break;
      case 87: /* conslist_opt ::= */
#line 328 "parse.y"
{yygotominor.yy0.n = 0; yygotominor.yy0.z = 0;}
#line 2386 "parse.c"
        break;
      case 88: /* conslist_opt ::= COMMA conslist */
#line 329 "parse.y"
{yygotominor.yy0 = yymsp[-1].minor.yy0;}
#line 2391 "parse.c"
        break;
      case 93: /* tcons ::= PRIMARY KEY LP idxlist autoinc RP onconf */
#line 335 "parse.y"
{sqlite3AddPrimaryKey(pParse,yymsp[-3].minor.yy148,yymsp[0].minor.yy194,yymsp[-2].minor.yy194,0);}
#line 2396 "parse.c"
        break;
      case 94: /* tcons ::= UNIQUE LP idxlist RP onconf */
#line 337 "parse.y"
{sqlite3CreateIndex(pParse,0,0,0,yymsp[-2].minor.yy148,yymsp[0].minor.yy194,0,0,0,0);}
#line 2401 "parse.c"
        break;
      case 95: /* tcons ::= CHECK LP expr RP onconf */
#line 338 "parse.y"
{sqlite3AddCheckConstraint(pParse,yymsp[-2].minor.yy72);}
#line 2406 "parse.c"
        break;
      case 96: /* tcons ::= FOREIGN KEY LP idxlist RP REFERENCES nm idxlist_opt refargs defer_subclause_opt */
#line 340 "parse.y"
{
    sqlite3CreateForeignKey(pParse, yymsp[-6].minor.yy148, &yymsp[-3].minor.yy0, yymsp[-2].minor.yy148, yymsp[-1].minor.yy194);
    sqlite3DeferForeignKey(pParse, yymsp[0].minor.yy194);
}
#line 2414 "parse.c"
        break;
      case 99: /* onconf ::= */
      case 101: /* orconf ::= */
#line 354 "parse.y"
{yygotominor.yy194 = OE_Default;}
#line 2420 "parse.c"
        break;
      case 104: /* resolvetype ::= IGNORE */
#line 359 "parse.y"
{yygotominor.yy194 = OE_Ignore;}
#line 2425 "parse.c"
        break;
      case 105: /* resolvetype ::= REPLACE */
      case 176: /* insert_cmd ::= REPLACE */
#line 360 "parse.y"
{yygotominor.yy194 = OE_Replace;}
#line 2431 "parse.c"
        break;
      case 106: /* cmd ::= DROP TABLE ifexists fullname */
#line 364 "parse.y"
{
  sqlite3DropTable(pParse, yymsp[0].minor.yy185, 0, yymsp[-1].minor.yy194);
}
#line 2438 "parse.c"
        break;
      case 109: /* cmd ::= createkw temp VIEW ifnotexists nm dbnm AS select */
#line 374 "parse.y"
{
  sqlite3CreateView(pParse, &yymsp[-7].minor.yy0, &yymsp[-3].minor.yy0, &yymsp[-2].minor.yy0, yymsp[0].minor.yy243, yymsp[-6].minor.yy194, yymsp[-4].minor.yy194);
}
#line 2445 "parse.c"
        break;
      case 110: /* cmd ::= DROP VIEW ifexists fullname */
#line 377 "parse.y"
{
  sqlite3DropTable(pParse, yymsp[0].minor.yy185, 1, yymsp[-1].minor.yy194);
}
#line 2452 "parse.c"
        break;
      case 111: /* cmd ::= select */
#line 384 "parse.y"
{
  SelectDest dest = {SRT_Output, 0, 0, 0, 0};
  sqlite3Select(pParse, yymsp[0].minor.yy243, &dest);
  sqlite3SelectDelete(pParse->db, yymsp[0].minor.yy243);
}
#line 2461 "parse.c"
        break;
      case 112: /* select ::= oneselect */
#line 395 "parse.y"
{yygotominor.yy243 = yymsp[0].minor.yy243;}
#line 2466 "parse.c"
        break;
      case 113: /* select ::= select multiselect_op oneselect */
#line 397 "parse.y"
{
  if( yymsp[0].minor.yy243 ){
    yymsp[0].minor.yy243->op = (u8)yymsp[-1].minor.yy194;
    yymsp[0].minor.yy243->pPrior = yymsp[-2].minor.yy243;
  }else{
    sqlite3SelectDelete(pParse->db, yymsp[-2].minor.yy243);
  }
  yygotominor.yy243 = yymsp[0].minor.yy243;
}
#line 2479 "parse.c"
        break;
      case 115: /* multiselect_op ::= UNION ALL */
#line 408 "parse.y"
{yygotominor.yy194 = TK_ALL;}
#line 2484 "parse.c"
        break;
      case 117: /* oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt */
#line 412 "parse.y"
{
  yygotominor.yy243 = sqlite3SelectNew(pParse,yymsp[-6].minor.yy148,yymsp[-5].minor.yy185,yymsp[-4].minor.yy72,yymsp[-3].minor.yy148,yymsp[-2].minor.yy72,yymsp[-1].minor.yy148,yymsp[-7].minor.yy194,yymsp[0].minor.yy354.pLimit,yymsp[0].minor.yy354.pOffset);
}
#line 2491 "parse.c"
        break;
      case 121: /* sclp ::= selcollist COMMA */
      case 247: /* idxlist_opt ::= LP idxlist RP */
#line 433 "parse.y"
{yygotominor.yy148 = yymsp[-1].minor.yy148;}
#line 2497 "parse.c"
        break;
      case 122: /* sclp ::= */
      case 150: /* orderby_opt ::= */
      case 158: /* groupby_opt ::= */
      case 240: /* exprlist ::= */
      case 246: /* idxlist_opt ::= */
#line 434 "parse.y"
{yygotominor.yy148 = 0;}
#line 2506 "parse.c"
        break;
      case 123: /* selcollist ::= sclp expr as */
#line 435 "parse.y"
{
   yygotominor.yy148 = sqlite3ExprListAppend(pParse,yymsp[-2].minor.yy148,yymsp[-1].minor.yy72,yymsp[0].minor.yy0.n?&yymsp[0].minor.yy0:0);
}
#line 2513 "parse.c"
        break;
      case 124: /* selcollist ::= sclp STAR */
#line 438 "parse.y"
{
  Expr *p = sqlite3PExpr(pParse, TK_ALL, 0, 0, 0);
  yygotominor.yy148 = sqlite3ExprListAppend(pParse, yymsp[-1].minor.yy148, p, 0);
}
#line 2521 "parse.c"
        break;
      case 125: /* selcollist ::= sclp nm DOT STAR */
#line 442 "parse.y"
{
  Expr *pRight = sqlite3PExpr(pParse, TK_ALL, 0, 0, &yymsp[0].minor.yy0);
  Expr *pLeft = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[-2].minor.yy0);
  Expr *pDot = sqlite3PExpr(pParse, TK_DOT, pLeft, pRight, 0);
  yygotominor.yy148 = sqlite3ExprListAppend(pParse,yymsp[-3].minor.yy148, pDot, 0);
}
#line 2531 "parse.c"
        break;
      case 128: /* as ::= */
#line 455 "parse.y"
{yygotominor.yy0.n = 0;}
#line 2536 "parse.c"
        break;
      case 129: /* from ::= */
#line 467 "parse.y"
{yygotominor.yy185 = sqlite3DbMallocZero(pParse->db, sizeof(*yygotominor.yy185));}
#line 2541 "parse.c"
        break;
      case 130: /* from ::= FROM seltablist */
#line 468 "parse.y"
{
  yygotominor.yy185 = yymsp[0].minor.yy185;
  sqlite3SrcListShiftJoinType(yygotominor.yy185);
}
#line 2549 "parse.c"
        break;
      case 131: /* stl_prefix ::= seltablist joinop */
#line 476 "parse.y"
{
   yygotominor.yy185 = yymsp[-1].minor.yy185;
   if( yygotominor.yy185 && yygotominor.yy185->nSrc>0 ) yygotominor.yy185->a[yygotominor.yy185->nSrc-1].jointype = (u8)yymsp[0].minor.yy194;
}
#line 2557 "parse.c"
        break;
      case 132: /* stl_prefix ::= */
#line 480 "parse.y"
{yygotominor.yy185 = 0;}
#line 2562 "parse.c"
        break;
      case 133: /* seltablist ::= stl_prefix nm dbnm as indexed_opt on_opt using_opt */
#line 481 "parse.y"
{
  yygotominor.yy185 = sqlite3SrcListAppendFromTerm(pParse,yymsp[-6].minor.yy185,&yymsp[-5].minor.yy0,&yymsp[-4].minor.yy0,&yymsp[-3].minor.yy0,0,yymsp[-1].minor.yy72,yymsp[0].minor.yy254);
  sqlite3SrcListIndexedBy(pParse, yygotominor.yy185, &yymsp[-2].minor.yy0);
}
#line 2570 "parse.c"
        break;
      case 134: /* seltablist ::= stl_prefix LP select RP as on_opt using_opt */
#line 487 "parse.y"
{
    yygotominor.yy185 = sqlite3SrcListAppendFromTerm(pParse,yymsp[-6].minor.yy185,0,0,&yymsp[-2].minor.yy0,yymsp[-4].minor.yy243,yymsp[-1].minor.yy72,yymsp[0].minor.yy254);
  }
#line 2577 "parse.c"
        break;
      case 135: /* seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt */
#line 491 "parse.y"
{
    if( yymsp[-6].minor.yy185==0 && yymsp[-2].minor.yy0.n==0 && yymsp[-1].minor.yy72==0 && yymsp[0].minor.yy254==0 ){
      yygotominor.yy185 = yymsp[-4].minor.yy185;
    }else{
      Select *pSubquery;
      sqlite3SrcListShiftJoinType(yymsp[-4].minor.yy185);
      pSubquery = sqlite3SelectNew(pParse,0,yymsp[-4].minor.yy185,0,0,0,0,0,0,0);
      yygotominor.yy185 = sqlite3SrcListAppendFromTerm(pParse,yymsp[-6].minor.yy185,0,0,&yymsp[-2].minor.yy0,pSubquery,yymsp[-1].minor.yy72,yymsp[0].minor.yy254);
    }
  }
#line 2591 "parse.c"
        break;
      case 136: /* dbnm ::= */
      case 145: /* indexed_opt ::= */
#line 516 "parse.y"
{yygotominor.yy0.z=0; yygotominor.yy0.n=0;}
#line 2597 "parse.c"
        break;
      case 138: /* fullname ::= nm dbnm */
#line 521 "parse.y"
{yygotominor.yy185 = sqlite3SrcListAppend(pParse->db,0,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy0);}
#line 2602 "parse.c"
        break;
      case 139: /* joinop ::= COMMA|JOIN */
#line 525 "parse.y"
{ yygotominor.yy194 = JT_INNER; }
#line 2607 "parse.c"
        break;
      case 140: /* joinop ::= JOIN_KW JOIN */
#line 526 "parse.y"
{ yygotominor.yy194 = sqlite3JoinType(pParse,&yymsp[-1].minor.yy0,0,0); }
#line 2612 "parse.c"
        break;
      case 141: /* joinop ::= JOIN_KW nm JOIN */
#line 527 "parse.y"
{ yygotominor.yy194 = sqlite3JoinType(pParse,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0,0); }
#line 2617 "parse.c"
        break;
      case 142: /* joinop ::= JOIN_KW nm nm JOIN */
#line 529 "parse.y"
{ yygotominor.yy194 = sqlite3JoinType(pParse,&yymsp[-3].minor.yy0,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0); }
#line 2622 "parse.c"
        break;
      case 143: /* on_opt ::= ON expr */
      case 154: /* sortitem ::= expr */
      case 161: /* having_opt ::= HAVING expr */
      case 168: /* where_opt ::= WHERE expr */
      case 183: /* expr ::= term */
      case 211: /* escape ::= ESCAPE expr */
      case 235: /* case_else ::= ELSE expr */
      case 237: /* case_operand ::= expr */
#line 533 "parse.y"
{yygotominor.yy72 = yymsp[0].minor.yy72;}
#line 2634 "parse.c"
        break;
      case 144: /* on_opt ::= */
      case 160: /* having_opt ::= */
      case 167: /* where_opt ::= */
      case 212: /* escape ::= */
      case 236: /* case_else ::= */
      case 238: /* case_operand ::= */
#line 534 "parse.y"
{yygotominor.yy72 = 0;}
#line 2644 "parse.c"
        break;
      case 147: /* indexed_opt ::= NOT INDEXED */
#line 549 "parse.y"
{yygotominor.yy0.z=0; yygotominor.yy0.n=1;}
#line 2649 "parse.c"
        break;
      case 148: /* using_opt ::= USING LP inscollist RP */
      case 180: /* inscollist_opt ::= LP inscollist RP */
#line 553 "parse.y"
{yygotominor.yy254 = yymsp[-1].minor.yy254;}
#line 2655 "parse.c"
        break;
      case 149: /* using_opt ::= */
      case 179: /* inscollist_opt ::= */
#line 554 "parse.y"
{yygotominor.yy254 = 0;}
#line 2661 "parse.c"
        break;
      case 151: /* orderby_opt ::= ORDER BY sortlist */
      case 159: /* groupby_opt ::= GROUP BY nexprlist */
      case 239: /* exprlist ::= nexprlist */
#line 565 "parse.y"
{yygotominor.yy148 = yymsp[0].minor.yy148;}
#line 2668 "parse.c"
        break;
      case 152: /* sortlist ::= sortlist COMMA sortitem sortorder */
#line 566 "parse.y"
{
  yygotominor.yy148 = sqlite3ExprListAppend(pParse,yymsp[-3].minor.yy148,yymsp[-1].minor.yy72,0);
  if( yygotominor.yy148 ) yygotominor.yy148->a[yygotominor.yy148->nExpr-1].sortOrder = (u8)yymsp[0].minor.yy194;
}
#line 2676 "parse.c"
        break;
      case 153: /* sortlist ::= sortitem sortorder */
#line 570 "parse.y"
{
  yygotominor.yy148 = sqlite3ExprListAppend(pParse,0,yymsp[-1].minor.yy72,0);
  if( yygotominor.yy148 && yygotominor.yy148->a ) yygotominor.yy148->a[0].sortOrder = (u8)yymsp[0].minor.yy194;
}
#line 2684 "parse.c"
        break;
      case 155: /* sortorder ::= ASC */
      case 157: /* sortorder ::= */
#line 578 "parse.y"
{yygotominor.yy194 = SQLITE_SO_ASC;}
#line 2690 "parse.c"
        break;
      case 156: /* sortorder ::= DESC */
#line 579 "parse.y"
{yygotominor.yy194 = SQLITE_SO_DESC;}
#line 2695 "parse.c"
        break;
      case 162: /* limit_opt ::= */
#line 605 "parse.y"
{yygotominor.yy354.pLimit = 0; yygotominor.yy354.pOffset = 0;}
#line 2700 "parse.c"
        break;
      case 163: /* limit_opt ::= LIMIT expr */
#line 606 "parse.y"
{yygotominor.yy354.pLimit = yymsp[0].minor.yy72; yygotominor.yy354.pOffset = 0;}
#line 2705 "parse.c"
        break;
      case 164: /* limit_opt ::= LIMIT expr OFFSET expr */
#line 608 "parse.y"
{yygotominor.yy354.pLimit = yymsp[-2].minor.yy72; yygotominor.yy354.pOffset = yymsp[0].minor.yy72;}
#line 2710 "parse.c"
        break;
      case 165: /* limit_opt ::= LIMIT expr COMMA expr */
#line 610 "parse.y"
{yygotominor.yy354.pOffset = yymsp[-2].minor.yy72; yygotominor.yy354.pLimit = yymsp[0].minor.yy72;}
#line 2715 "parse.c"
        break;
      case 166: /* cmd ::= DELETE FROM fullname indexed_opt where_opt */
#line 623 "parse.y"
{
  sqlite3SrcListIndexedBy(pParse, yymsp[-2].minor.yy185, &yymsp[-1].minor.yy0);
  sqlite3DeleteFrom(pParse,yymsp[-2].minor.yy185,yymsp[0].minor.yy72);
}
#line 2723 "parse.c"
        break;
      case 169: /* cmd ::= UPDATE orconf fullname indexed_opt SET setlist where_opt */
#line 646 "parse.y"
{
  sqlite3SrcListIndexedBy(pParse, yymsp[-4].minor.yy185, &yymsp[-3].minor.yy0);
  sqlite3ExprListCheckLength(pParse,yymsp[-1].minor.yy148,"set list"); 
  sqlite3Update(pParse,yymsp[-4].minor.yy185,yymsp[-1].minor.yy148,yymsp[0].minor.yy72,yymsp[-5].minor.yy194);
}
#line 2732 "parse.c"
        break;
      case 170: /* setlist ::= setlist COMMA nm EQ expr */
#line 657 "parse.y"
{yygotominor.yy148 = sqlite3ExprListAppend(pParse,yymsp[-4].minor.yy148,yymsp[0].minor.yy72,&yymsp[-2].minor.yy0);}
#line 2737 "parse.c"
        break;
      case 171: /* setlist ::= nm EQ expr */
#line 659 "parse.y"
{yygotominor.yy148 = sqlite3ExprListAppend(pParse,0,yymsp[0].minor.yy72,&yymsp[-2].minor.yy0);}
#line 2742 "parse.c"
        break;
      case 172: /* cmd ::= insert_cmd INTO fullname inscollist_opt VALUES LP itemlist RP */
#line 665 "parse.y"
{sqlite3Insert(pParse, yymsp[-5].minor.yy185, yymsp[-1].minor.yy148, 0, yymsp[-4].minor.yy254, yymsp[-7].minor.yy194);}
#line 2747 "parse.c"
        break;
      case 173: /* cmd ::= insert_cmd INTO fullname inscollist_opt select */
#line 667 "parse.y"
{sqlite3Insert(pParse, yymsp[-2].minor.yy185, 0, yymsp[0].minor.yy243, yymsp[-1].minor.yy254, yymsp[-4].minor.yy194);}
#line 2752 "parse.c"
        break;
      case 174: /* cmd ::= insert_cmd INTO fullname inscollist_opt DEFAULT VALUES */
#line 669 "parse.y"
{sqlite3Insert(pParse, yymsp[-3].minor.yy185, 0, 0, yymsp[-2].minor.yy254, yymsp[-5].minor.yy194);}
#line 2757 "parse.c"
        break;
      case 177: /* itemlist ::= itemlist COMMA expr */
      case 241: /* nexprlist ::= nexprlist COMMA expr */
#line 680 "parse.y"
{yygotominor.yy148 = sqlite3ExprListAppend(pParse,yymsp[-2].minor.yy148,yymsp[0].minor.yy72,0);}
#line 2763 "parse.c"
        break;
      case 178: /* itemlist ::= expr */
      case 242: /* nexprlist ::= expr */
#line 682 "parse.y"
{yygotominor.yy148 = sqlite3ExprListAppend(pParse,0,yymsp[0].minor.yy72,0);}
#line 2769 "parse.c"
        break;
      case 181: /* inscollist ::= inscollist COMMA nm */
#line 692 "parse.y"
{yygotominor.yy254 = sqlite3IdListAppend(pParse->db,yymsp[-2].minor.yy254,&yymsp[0].minor.yy0);}
#line 2774 "parse.c"
        break;
      case 182: /* inscollist ::= nm */
#line 694 "parse.y"
{yygotominor.yy254 = sqlite3IdListAppend(pParse->db,0,&yymsp[0].minor.yy0);}
#line 2779 "parse.c"
        break;
      case 184: /* expr ::= LP expr RP */
#line 705 "parse.y"
{yygotominor.yy72 = yymsp[-1].minor.yy72; sqlite3ExprSpan(yygotominor.yy72,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); }
#line 2784 "parse.c"
        break;
      case 185: /* term ::= NULL */
      case 190: /* term ::= INTEGER|FLOAT|BLOB */
      case 191: /* term ::= STRING */
#line 706 "parse.y"
{yygotominor.yy72 = sqlite3PExpr(pParse, yymsp[0].major, 0, 0, &yymsp[0].minor.yy0);}
#line 2791 "parse.c"
        break;
      case 186: /* expr ::= id */
      case 187: /* expr ::= JOIN_KW */
#line 707 "parse.y"
{yygotominor.yy72 = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[0].minor.yy0);}
#line 2797 "parse.c"
        break;
      case 188: /* expr ::= nm DOT nm */
#line 709 "parse.y"
{
  Expr *temp1 = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[-2].minor.yy0);
  Expr *temp2 = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[0].minor.yy0);
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_DOT, temp1, temp2, 0);
}
#line 2806 "parse.c"
        break;
      case 189: /* expr ::= nm DOT nm DOT nm */
#line 714 "parse.y"
{
  Expr *temp1 = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[-4].minor.yy0);
  Expr *temp2 = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[-2].minor.yy0);
  Expr *temp3 = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[0].minor.yy0);
  Expr *temp4 = sqlite3PExpr(pParse, TK_DOT, temp2, temp3, 0);
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_DOT, temp1, temp4, 0);
}
#line 2817 "parse.c"
        break;
      case 192: /* expr ::= REGISTER */
#line 723 "parse.y"
{yygotominor.yy72 = sqlite3RegisterExpr(pParse, &yymsp[0].minor.yy0);}
#line 2822 "parse.c"
        break;
      case 193: /* expr ::= VARIABLE */
#line 724 "parse.y"
{
  Token *pToken = &yymsp[0].minor.yy0;
  Expr *pExpr = yygotominor.yy72 = sqlite3PExpr(pParse, TK_VARIABLE, 0, 0, pToken);
  sqlite3ExprAssignVarNumber(pParse, pExpr);
}
#line 2831 "parse.c"
        break;
      case 194: /* expr ::= expr COLLATE ids */
#line 729 "parse.y"
{
  yygotominor.yy72 = sqlite3ExprSetColl(pParse, yymsp[-2].minor.yy72, &yymsp[0].minor.yy0);
}
#line 2838 "parse.c"
        break;
      case 195: /* expr ::= CAST LP expr AS typetoken RP */
#line 733 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_CAST, yymsp[-3].minor.yy72, 0, &yymsp[-1].minor.yy0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0);
}
#line 2846 "parse.c"
        break;
      case 196: /* expr ::= ID LP distinct exprlist RP */
#line 738 "parse.y"
{
  if( yymsp[-1].minor.yy148 && yymsp[-1].minor.yy148->nExpr>SQLITE_MAX_FUNCTION_ARG ){
    sqlite3ErrorMsg(pParse, "too many arguments on function %T", &yymsp[-4].minor.yy0);
  }
  yygotominor.yy72 = sqlite3ExprFunction(pParse, yymsp[-1].minor.yy148, &yymsp[-4].minor.yy0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);
  if( yymsp[-2].minor.yy194 && yygotominor.yy72 ){
    yygotominor.yy72->flags |= EP_Distinct;
  }
}
#line 2860 "parse.c"
        break;
      case 197: /* expr ::= ID LP STAR RP */
#line 748 "parse.y"
{
  yygotominor.yy72 = sqlite3ExprFunction(pParse, 0, &yymsp[-3].minor.yy0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);
}
#line 2868 "parse.c"
        break;
      case 198: /* term ::= CTIME_KW */
#line 752 "parse.y"
{
  /* The CURRENT_TIME, CURRENT_DATE, and CURRENT_TIMESTAMP values are
  ** treated as functions that return constants */
  yygotominor.yy72 = sqlite3ExprFunction(pParse, 0,&yymsp[0].minor.yy0);
  if( yygotominor.yy72 ){
    yygotominor.yy72->op = TK_CONST_FUNC;  
    yygotominor.yy72->span = yymsp[0].minor.yy0;
  }
}
#line 2881 "parse.c"
        break;
      case 199: /* expr ::= expr AND expr */
      case 200: /* expr ::= expr OR expr */
      case 201: /* expr ::= expr LT|GT|GE|LE expr */
      case 202: /* expr ::= expr EQ|NE expr */
      case 203: /* expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr */
      case 204: /* expr ::= expr PLUS|MINUS expr */
      case 205: /* expr ::= expr STAR|SLASH|REM expr */
      case 206: /* expr ::= expr CONCAT expr */
#line 761 "parse.y"
{yygotominor.yy72 = sqlite3PExpr(pParse,yymsp[-1].major,yymsp[-2].minor.yy72,yymsp[0].minor.yy72,0);}
#line 2893 "parse.c"
        break;
      case 207: /* likeop ::= LIKE_KW */
      case 209: /* likeop ::= MATCH */
#line 773 "parse.y"
{yygotominor.yy392.eOperator = yymsp[0].minor.yy0; yygotominor.yy392.not = 0;}
#line 2899 "parse.c"
        break;
      case 208: /* likeop ::= NOT LIKE_KW */
      case 210: /* likeop ::= NOT MATCH */
#line 774 "parse.y"
{yygotominor.yy392.eOperator = yymsp[0].minor.yy0; yygotominor.yy392.not = 1;}
#line 2905 "parse.c"
        break;
      case 213: /* expr ::= expr likeop expr escape */
#line 781 "parse.y"
{
  ExprList *pList;
  pList = sqlite3ExprListAppend(pParse,0, yymsp[-1].minor.yy72, 0);
  pList = sqlite3ExprListAppend(pParse,pList, yymsp[-3].minor.yy72, 0);
  if( yymsp[0].minor.yy72 ){
    pList = sqlite3ExprListAppend(pParse,pList, yymsp[0].minor.yy72, 0);
  }
  yygotominor.yy72 = sqlite3ExprFunction(pParse, pList, &yymsp[-2].minor.yy392.eOperator);
  if( yymsp[-2].minor.yy392.not ) yygotominor.yy72 = sqlite3PExpr(pParse, TK_NOT, yygotominor.yy72, 0, 0);
  sqlite3ExprSpan(yygotominor.yy72, &yymsp[-3].minor.yy72->span, &yymsp[-1].minor.yy72->span);
  if( yygotominor.yy72 ) yygotominor.yy72->flags |= EP_InfixFunc;
}
#line 2921 "parse.c"
        break;
      case 214: /* expr ::= expr ISNULL|NOTNULL */
#line 794 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, yymsp[0].major, yymsp[-1].minor.yy72, 0, 0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-1].minor.yy72->span,&yymsp[0].minor.yy0);
}
#line 2929 "parse.c"
        break;
      case 215: /* expr ::= expr IS NULL */
#line 798 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_ISNULL, yymsp[-2].minor.yy72, 0, 0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-2].minor.yy72->span,&yymsp[0].minor.yy0);
}
#line 2937 "parse.c"
        break;
      case 216: /* expr ::= expr NOT NULL */
#line 802 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_NOTNULL, yymsp[-2].minor.yy72, 0, 0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-2].minor.yy72->span,&yymsp[0].minor.yy0);
}
#line 2945 "parse.c"
        break;
      case 217: /* expr ::= expr IS NOT NULL */
#line 806 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_NOTNULL, yymsp[-3].minor.yy72, 0, 0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-3].minor.yy72->span,&yymsp[0].minor.yy0);
}
#line 2953 "parse.c"
        break;
      case 218: /* expr ::= NOT expr */
      case 219: /* expr ::= BITNOT expr */
#line 810 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, yymsp[-1].major, yymsp[0].minor.yy72, 0, 0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy72->span);
}
#line 2962 "parse.c"
        break;
      case 220: /* expr ::= MINUS expr */
#line 818 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_UMINUS, yymsp[0].minor.yy72, 0, 0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy72->span);
}
#line 2970 "parse.c"
        break;
      case 221: /* expr ::= PLUS expr */
#line 822 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_UPLUS, yymsp[0].minor.yy72, 0, 0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy72->span);
}
#line 2978 "parse.c"
        break;
      case 224: /* expr ::= expr between_op expr AND expr */
#line 829 "parse.y"
{
  ExprList *pList = sqlite3ExprListAppend(pParse,0, yymsp[-2].minor.yy72, 0);
  pList = sqlite3ExprListAppend(pParse,pList, yymsp[0].minor.yy72, 0);
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_BETWEEN, yymsp[-4].minor.yy72, 0, 0);
  if( yygotominor.yy72 ){
    yygotominor.yy72->x.pList = pList;
  }else{
    sqlite3ExprListDelete(pParse->db, pList);
  } 
  if( yymsp[-3].minor.yy194 ) yygotominor.yy72 = sqlite3PExpr(pParse, TK_NOT, yygotominor.yy72, 0, 0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-4].minor.yy72->span,&yymsp[0].minor.yy72->span);
}
#line 2994 "parse.c"
        break;
      case 227: /* expr ::= expr in_op LP exprlist RP */
#line 845 "parse.y"
{
    yygotominor.yy72 = sqlite3PExpr(pParse, TK_IN, yymsp[-4].minor.yy72, 0, 0);
    if( yygotominor.yy72 ){
      yygotominor.yy72->x.pList = yymsp[-1].minor.yy148;
      sqlite3ExprSetHeight(pParse, yygotominor.yy72);
    }else{
      sqlite3ExprListDelete(pParse->db, yymsp[-1].minor.yy148);
    }
    if( yymsp[-3].minor.yy194 ) yygotominor.yy72 = sqlite3PExpr(pParse, TK_NOT, yygotominor.yy72, 0, 0);
    sqlite3ExprSpan(yygotominor.yy72,&yymsp[-4].minor.yy72->span,&yymsp[0].minor.yy0);
  }
#line 3009 "parse.c"
        break;
      case 228: /* expr ::= LP select RP */
#line 856 "parse.y"
{
    yygotominor.yy72 = sqlite3PExpr(pParse, TK_SELECT, 0, 0, 0);
    if( yygotominor.yy72 ){
      yygotominor.yy72->x.pSelect = yymsp[-1].minor.yy243;
      ExprSetProperty(yygotominor.yy72, EP_xIsSelect);
      sqlite3ExprSetHeight(pParse, yygotominor.yy72);
    }else{
      sqlite3SelectDelete(pParse->db, yymsp[-1].minor.yy243);
    }
    sqlite3ExprSpan(yygotominor.yy72,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0);
  }
#line 3024 "parse.c"
        break;
      case 229: /* expr ::= expr in_op LP select RP */
#line 867 "parse.y"
{
    yygotominor.yy72 = sqlite3PExpr(pParse, TK_IN, yymsp[-4].minor.yy72, 0, 0);
    if( yygotominor.yy72 ){
      yygotominor.yy72->x.pSelect = yymsp[-1].minor.yy243;
      ExprSetProperty(yygotominor.yy72, EP_xIsSelect);
      sqlite3ExprSetHeight(pParse, yygotominor.yy72);
    }else{
      sqlite3SelectDelete(pParse->db, yymsp[-1].minor.yy243);
    }
    if( yymsp[-3].minor.yy194 ) yygotominor.yy72 = sqlite3PExpr(pParse, TK_NOT, yygotominor.yy72, 0, 0);
    sqlite3ExprSpan(yygotominor.yy72,&yymsp[-4].minor.yy72->span,&yymsp[0].minor.yy0);
  }
#line 3040 "parse.c"
        break;
      case 230: /* expr ::= expr in_op nm dbnm */
#line 879 "parse.y"
{
    SrcList *pSrc = sqlite3SrcListAppend(pParse->db, 0,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy0);
    yygotominor.yy72 = sqlite3PExpr(pParse, TK_IN, yymsp[-3].minor.yy72, 0, 0);
    if( yygotominor.yy72 ){
      yygotominor.yy72->x.pSelect = sqlite3SelectNew(pParse, 0,pSrc,0,0,0,0,0,0,0);
      ExprSetProperty(yygotominor.yy72, EP_xIsSelect);
      sqlite3ExprSetHeight(pParse, yygotominor.yy72);
    }else{
      sqlite3SrcListDelete(pParse->db, pSrc);
    }
    if( yymsp[-2].minor.yy194 ) yygotominor.yy72 = sqlite3PExpr(pParse, TK_NOT, yygotominor.yy72, 0, 0);
    sqlite3ExprSpan(yygotominor.yy72,&yymsp[-3].minor.yy72->span,yymsp[0].minor.yy0.z?&yymsp[0].minor.yy0:&yymsp[-1].minor.yy0);
  }
#line 3057 "parse.c"
        break;
      case 231: /* expr ::= EXISTS LP select RP */
#line 892 "parse.y"
{
    Expr *p = yygotominor.yy72 = sqlite3PExpr(pParse, TK_EXISTS, 0, 0, 0);
    if( p ){
      p->x.pSelect = yymsp[-1].minor.yy243;
      ExprSetProperty(yygotominor.yy72, EP_xIsSelect);
      sqlite3ExprSpan(p,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);
      sqlite3ExprSetHeight(pParse, yygotominor.yy72);
    }else{
      sqlite3SelectDelete(pParse->db, yymsp[-1].minor.yy243);
    }
  }
#line 3072 "parse.c"
        break;
      case 232: /* expr ::= CASE case_operand case_exprlist case_else END */
#line 906 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_CASE, yymsp[-3].minor.yy72, yymsp[-1].minor.yy72, 0);
  if( yygotominor.yy72 ){
    yygotominor.yy72->x.pList = yymsp[-2].minor.yy148;
    sqlite3ExprSetHeight(pParse, yygotominor.yy72);
  }else{
    sqlite3ExprListDelete(pParse->db, yymsp[-2].minor.yy148);
  }
  sqlite3ExprSpan(yygotominor.yy72, &yymsp[-4].minor.yy0, &yymsp[0].minor.yy0);
}
#line 3086 "parse.c"
        break;
      case 233: /* case_exprlist ::= case_exprlist WHEN expr THEN expr */
#line 918 "parse.y"
{
  yygotominor.yy148 = sqlite3ExprListAppend(pParse,yymsp[-4].minor.yy148, yymsp[-2].minor.yy72, 0);
  yygotominor.yy148 = sqlite3ExprListAppend(pParse,yygotominor.yy148, yymsp[0].minor.yy72, 0);
}
#line 3094 "parse.c"
        break;
      case 234: /* case_exprlist ::= WHEN expr THEN expr */
#line 922 "parse.y"
{
  yygotominor.yy148 = sqlite3ExprListAppend(pParse,0, yymsp[-2].minor.yy72, 0);
  yygotominor.yy148 = sqlite3ExprListAppend(pParse,yygotominor.yy148, yymsp[0].minor.yy72, 0);
}
#line 3102 "parse.c"
        break;
      case 243: /* cmd ::= createkw uniqueflag INDEX ifnotexists nm dbnm ON nm LP idxlist RP */
#line 951 "parse.y"
{
  sqlite3CreateIndex(pParse, &yymsp[-6].minor.yy0, &yymsp[-5].minor.yy0, 
                     sqlite3SrcListAppend(pParse->db,0,&yymsp[-3].minor.yy0,0), yymsp[-1].minor.yy148, yymsp[-9].minor.yy194,
                      &yymsp[-10].minor.yy0, &yymsp[0].minor.yy0, SQLITE_SO_ASC, yymsp[-7].minor.yy194);
}
#line 3111 "parse.c"
        break;
      case 244: /* uniqueflag ::= UNIQUE */
      case 293: /* raisetype ::= ABORT */
#line 958 "parse.y"
{yygotominor.yy194 = OE_Abort;}
#line 3117 "parse.c"
        break;
      case 245: /* uniqueflag ::= */
#line 959 "parse.y"
{yygotominor.yy194 = OE_None;}
#line 3122 "parse.c"
        break;
      case 248: /* idxlist ::= idxlist COMMA nm collate sortorder */
#line 968 "parse.y"
{
  Expr *p = 0;
  if( yymsp[-1].minor.yy0.n>0 ){
    p = sqlite3PExpr(pParse, TK_COLUMN, 0, 0, 0);
    sqlite3ExprSetColl(pParse, p, &yymsp[-1].minor.yy0);
  }
  yygotominor.yy148 = sqlite3ExprListAppend(pParse,yymsp[-4].minor.yy148, p, &yymsp[-2].minor.yy0);
  sqlite3ExprListCheckLength(pParse, yygotominor.yy148, "index");
  if( yygotominor.yy148 ) yygotominor.yy148->a[yygotominor.yy148->nExpr-1].sortOrder = (u8)yymsp[0].minor.yy194;
}
#line 3136 "parse.c"
        break;
      case 249: /* idxlist ::= nm collate sortorder */
#line 978 "parse.y"
{
  Expr *p = 0;
  if( yymsp[-1].minor.yy0.n>0 ){
    p = sqlite3PExpr(pParse, TK_COLUMN, 0, 0, 0);
    sqlite3ExprSetColl(pParse, p, &yymsp[-1].minor.yy0);
  }
  yygotominor.yy148 = sqlite3ExprListAppend(pParse,0, p, &yymsp[-2].minor.yy0);
  sqlite3ExprListCheckLength(pParse, yygotominor.yy148, "index");
  if( yygotominor.yy148 ) yygotominor.yy148->a[yygotominor.yy148->nExpr-1].sortOrder = (u8)yymsp[0].minor.yy194;
}
#line 3150 "parse.c"
        break;
      case 250: /* collate ::= */
#line 990 "parse.y"
{yygotominor.yy0.z = 0; yygotominor.yy0.n = 0;}
#line 3155 "parse.c"
        break;
      case 252: /* cmd ::= DROP INDEX ifexists fullname */
#line 996 "parse.y"
{sqlite3DropIndex(pParse, yymsp[0].minor.yy185, yymsp[-1].minor.yy194);}
#line 3160 "parse.c"
        break;
      case 253: /* cmd ::= VACUUM */
      case 254: /* cmd ::= VACUUM nm */
#line 1002 "parse.y"
{sqlite3Vacuum(pParse);}
#line 3166 "parse.c"
        break;
      case 255: /* cmd ::= PRAGMA nm dbnm */
#line 1011 "parse.y"
{sqlite3Pragma(pParse,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy0,0,0);}
#line 3171 "parse.c"
        break;
      case 256: /* cmd ::= PRAGMA nm dbnm EQ nmnum */
#line 1012 "parse.y"
{sqlite3Pragma(pParse,&yymsp[-3].minor.yy0,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0,0);}
#line 3176 "parse.c"
        break;
      case 257: /* cmd ::= PRAGMA nm dbnm LP nmnum RP */
#line 1013 "parse.y"
{sqlite3Pragma(pParse,&yymsp[-4].minor.yy0,&yymsp[-3].minor.yy0,&yymsp[-1].minor.yy0,0);}
#line 3181 "parse.c"
        break;
      case 258: /* cmd ::= PRAGMA nm dbnm EQ minus_num */
#line 1015 "parse.y"
{sqlite3Pragma(pParse,&yymsp[-3].minor.yy0,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0,1);}
#line 3186 "parse.c"
        break;
      case 259: /* cmd ::= PRAGMA nm dbnm LP minus_num RP */
#line 1017 "parse.y"
{sqlite3Pragma(pParse,&yymsp[-4].minor.yy0,&yymsp[-3].minor.yy0,&yymsp[-1].minor.yy0,1);}
#line 3191 "parse.c"
        break;
      case 270: /* cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END */
#line 1036 "parse.y"
{
  Token all;
  all.z = yymsp[-3].minor.yy0.z;
  all.n = (int)(yymsp[0].minor.yy0.z - yymsp[-3].minor.yy0.z) + yymsp[0].minor.yy0.n;
  sqlite3FinishTrigger(pParse, yymsp[-1].minor.yy145, &all);
}
#line 3201 "parse.c"
        break;
      case 271: /* trigger_decl ::= temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON fullname foreach_clause when_clause */
#line 1045 "parse.y"
{
  sqlite3BeginTrigger(pParse, &yymsp[-7].minor.yy0, &yymsp[-6].minor.yy0, yymsp[-5].minor.yy194, yymsp[-4].minor.yy332.a, yymsp[-4].minor.yy332.b, yymsp[-2].minor.yy185, yymsp[0].minor.yy72, yymsp[-10].minor.yy194, yymsp[-8].minor.yy194);
  yygotominor.yy0 = (yymsp[-6].minor.yy0.n==0?yymsp[-7].minor.yy0:yymsp[-6].minor.yy0);
}
#line 3209 "parse.c"
        break;
      case 272: /* trigger_time ::= BEFORE */
      case 275: /* trigger_time ::= */
#line 1051 "parse.y"
{ yygotominor.yy194 = TK_BEFORE; }
#line 3215 "parse.c"
        break;
      case 273: /* trigger_time ::= AFTER */
#line 1052 "parse.y"
{ yygotominor.yy194 = TK_AFTER;  }
#line 3220 "parse.c"
        break;
      case 274: /* trigger_time ::= INSTEAD OF */
#line 1053 "parse.y"
{ yygotominor.yy194 = TK_INSTEAD;}
#line 3225 "parse.c"
        break;
      case 276: /* trigger_event ::= DELETE|INSERT */
      case 277: /* trigger_event ::= UPDATE */
#line 1058 "parse.y"
{yygotominor.yy332.a = yymsp[0].major; yygotominor.yy332.b = 0;}
#line 3231 "parse.c"
        break;
      case 278: /* trigger_event ::= UPDATE OF inscollist */
#line 1060 "parse.y"
{yygotominor.yy332.a = TK_UPDATE; yygotominor.yy332.b = yymsp[0].minor.yy254;}
#line 3236 "parse.c"
        break;
      case 281: /* when_clause ::= */
      case 298: /* key_opt ::= */
#line 1067 "parse.y"
{ yygotominor.yy72 = 0; }
#line 3242 "parse.c"
        break;
      case 282: /* when_clause ::= WHEN expr */
      case 299: /* key_opt ::= KEY expr */
#line 1068 "parse.y"
{ yygotominor.yy72 = yymsp[0].minor.yy72; }
#line 3248 "parse.c"
        break;
      case 283: /* trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI */
#line 1072 "parse.y"
{
/*
  if( yymsp[-2].minor.yy145 ){
    yymsp[-2].minor.yy145->pLast->pNext = yymsp[-1].minor.yy145;
  }else{
    yymsp[-2].minor.yy145 = yymsp[-1].minor.yy145;
  }
*/
  assert( yymsp[-2].minor.yy145!=0 );
  yymsp[-2].minor.yy145->pLast->pNext = yymsp[-1].minor.yy145;
  yymsp[-2].minor.yy145->pLast = yymsp[-1].minor.yy145;
  yygotominor.yy145 = yymsp[-2].minor.yy145;
}
#line 3265 "parse.c"
        break;
      case 284: /* trigger_cmd_list ::= trigger_cmd SEMI */
#line 1085 "parse.y"
{ 
  /* if( yymsp[-1].minor.yy145 ) */
  assert( yymsp[-1].minor.yy145!=0 );
  yymsp[-1].minor.yy145->pLast = yymsp[-1].minor.yy145;
  yygotominor.yy145 = yymsp[-1].minor.yy145;
}
#line 3275 "parse.c"
        break;
      case 285: /* trigger_cmd ::= UPDATE orconf nm SET setlist where_opt */
#line 1096 "parse.y"
{ yygotominor.yy145 = sqlite3TriggerUpdateStep(pParse->db, &yymsp[-3].minor.yy0, yymsp[-1].minor.yy148, yymsp[0].minor.yy72, yymsp[-4].minor.yy194); }
#line 3280 "parse.c"
        break;
      case 286: /* trigger_cmd ::= insert_cmd INTO nm inscollist_opt VALUES LP itemlist RP */
#line 1101 "parse.y"
{yygotominor.yy145 = sqlite3TriggerInsertStep(pParse->db, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy254, yymsp[-1].minor.yy148, 0, yymsp[-7].minor.yy194);}
#line 3285 "parse.c"
        break;
      case 287: /* trigger_cmd ::= insert_cmd INTO nm inscollist_opt select */
#line 1104 "parse.y"
{yygotominor.yy145 = sqlite3TriggerInsertStep(pParse->db, &yymsp[-2].minor.yy0, yymsp[-1].minor.yy254, 0, yymsp[0].minor.yy243, yymsp[-4].minor.yy194);}
#line 3290 "parse.c"
        break;
      case 288: /* trigger_cmd ::= DELETE FROM nm where_opt */
#line 1108 "parse.y"
{yygotominor.yy145 = sqlite3TriggerDeleteStep(pParse->db, &yymsp[-1].minor.yy0, yymsp[0].minor.yy72);}
#line 3295 "parse.c"
        break;
      case 289: /* trigger_cmd ::= select */
#line 1111 "parse.y"
{yygotominor.yy145 = sqlite3TriggerSelectStep(pParse->db, yymsp[0].minor.yy243); }
#line 3300 "parse.c"
        break;
      case 290: /* expr ::= RAISE LP IGNORE RP */
#line 1114 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_RAISE, 0, 0, 0); 
  if( yygotominor.yy72 ){
    yygotominor.yy72->affinity = OE_Ignore;
    sqlite3ExprSpan(yygotominor.yy72, &yymsp[-3].minor.yy0, &yymsp[0].minor.yy0);
  }
}
#line 3311 "parse.c"
        break;
      case 291: /* expr ::= RAISE LP raisetype COMMA nm RP */
#line 1121 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_RAISE, 0, 0, &yymsp[-1].minor.yy0); 
  if( yygotominor.yy72 ) {
    yygotominor.yy72->affinity = (char)yymsp[-3].minor.yy194;
    sqlite3ExprSpan(yygotominor.yy72, &yymsp[-5].minor.yy0, &yymsp[0].minor.yy0);
  }
}
#line 3322 "parse.c"
        break;
      case 292: /* raisetype ::= ROLLBACK */
#line 1131 "parse.y"
{yygotominor.yy194 = OE_Rollback;}
#line 3327 "parse.c"
        break;
      case 294: /* raisetype ::= FAIL */
#line 1133 "parse.y"
{yygotominor.yy194 = OE_Fail;}
#line 3332 "parse.c"
        break;
      case 295: /* cmd ::= DROP TRIGGER ifexists fullname */
#line 1138 "parse.y"
{
  sqlite3DropTrigger(pParse,yymsp[0].minor.yy185,yymsp[-1].minor.yy194);
}
#line 3339 "parse.c"
        break;
      case 296: /* cmd ::= ATTACH database_kw_opt expr AS expr key_opt */
#line 1145 "parse.y"
{
  sqlite3Attach(pParse, yymsp[-3].minor.yy72, yymsp[-1].minor.yy72, yymsp[0].minor.yy72);
}
#line 3346 "parse.c"
        break;
      case 297: /* cmd ::= DETACH database_kw_opt expr */
#line 1148 "parse.y"
{
  sqlite3Detach(pParse, yymsp[0].minor.yy72);
}
#line 3353 "parse.c"
        break;
      case 302: /* cmd ::= REINDEX */
#line 1163 "parse.y"
{sqlite3Reindex(pParse, 0, 0);}
#line 3358 "parse.c"
        break;
      case 303: /* cmd ::= REINDEX nm dbnm */
#line 1164 "parse.y"
{sqlite3Reindex(pParse, &yymsp[-1].minor.yy0, &yymsp[0].minor.yy0);}
#line 3363 "parse.c"
        break;
      case 304: /* cmd ::= ANALYZE */
#line 1169 "parse.y"
{sqlite3Analyze(pParse, 0, 0);}
#line 3368 "parse.c"
        break;
      case 305: /* cmd ::= ANALYZE nm dbnm */
#line 1170 "parse.y"
{sqlite3Analyze(pParse, &yymsp[-1].minor.yy0, &yymsp[0].minor.yy0);}
#line 3373 "parse.c"
        break;
      case 306: /* cmd ::= ALTER TABLE fullname RENAME TO nm */
#line 1175 "parse.y"
{
  sqlite3AlterRenameTable(pParse,yymsp[-3].minor.yy185,&yymsp[0].minor.yy0);
}
#line 3380 "parse.c"
        break;
      case 307: /* cmd ::= ALTER TABLE add_column_fullname ADD kwcolumn_opt column */
#line 1178 "parse.y"
{
  sqlite3AlterFinishAddColumn(pParse, &yymsp[0].minor.yy0);
}
#line 3387 "parse.c"
        break;
      case 308: /* add_column_fullname ::= fullname */
#line 1181 "parse.y"
{
  pParse->db->lookaside.bEnabled = 0;
  sqlite3AlterBeginAddColumn(pParse, yymsp[0].minor.yy185);
}
#line 3395 "parse.c"
        break;
      case 311: /* cmd ::= create_vtab */
#line 1191 "parse.y"
{sqlite3VtabFinishParse(pParse,0);}
#line 3400 "parse.c"
        break;
      case 312: /* cmd ::= create_vtab LP vtabarglist RP */
#line 1192 "parse.y"
{sqlite3VtabFinishParse(pParse,&yymsp[0].minor.yy0);}
#line 3405 "parse.c"
        break;
      case 313: /* create_vtab ::= createkw VIRTUAL TABLE nm dbnm USING nm */
#line 1193 "parse.y"
{
    sqlite3VtabBeginParse(pParse, &yymsp[-3].minor.yy0, &yymsp[-2].minor.yy0, &yymsp[0].minor.yy0);
}
#line 3412 "parse.c"
        break;
      case 316: /* vtabarg ::= */
#line 1198 "parse.y"
{sqlite3VtabArgInit(pParse);}
#line 3417 "parse.c"
        break;
      case 318: /* vtabargtoken ::= ANY */
      case 319: /* vtabargtoken ::= lp anylist RP */
      case 320: /* lp ::= LP */
      case 322: /* anylist ::= anylist ANY */
#line 1200 "parse.y"
{sqlite3VtabArgExtend(pParse,&yymsp[0].minor.yy0);}
#line 3425 "parse.c"
        break;
  };
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yypParser->yyidx -= yysize;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact < YYNSTATE ){
#ifdef NDEBUG
    /* If we are not debugging and the reduce action popped at least
    ** one element off the stack, then we can push the new element back
    ** onto the stack here, and skip the stack overflow test in yy_shift().
    ** That gives a significant speed improvement. */
    if( yysize ){
      yypParser->yyidx++;
      yymsp -= yysize-1;
      yymsp->stateno = (YYACTIONTYPE)yyact;
      yymsp->major = (YYCODETYPE)yygoto;
      yymsp->minor = yygotominor;
    }else
#endif
    {
      yy_shift(yypParser,yyact,yygoto,&yygotominor);
    }
  }else{
    assert( yyact == YYNSTATE + YYNRULE + 1 );
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  sqlite3ParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
  sqlite3ParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  YYMINORTYPE yyminor            /* The minor type of the error token */
){
  sqlite3ParserARG_FETCH;
#define TOKEN (yyminor.yy0)
#line 34 "parse.y"

  UNUSED_PARAMETER(yymajor);  /* Silence some compiler warnings */
  assert( TOKEN.z[0] );  /* The tokenizer always gives us a token */
  sqlite3ErrorMsg(pParse, "near \"%T\": syntax error", &TOKEN);
  pParse->parseError = 1;
#line 3489 "parse.c"
  sqlite3ParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  sqlite3ParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
  sqlite3ParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "sqlite3ParserAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void sqlite3Parser(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  sqlite3ParserTOKENTYPE yyminor       /* The value for the token */
  sqlite3ParserARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  int yyact;            /* The parser action. */
  int yyendofinput;     /* True if we are at the end of input */
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  /* (re)initialize the parser, if necessary */
  yypParser = (yyParser*)yyp;
  if( yypParser->yyidx<0 ){
#if YYSTACKDEPTH<=0
    if( yypParser->yystksz <=0 ){
      /*memset(&yyminorunion, 0, sizeof(yyminorunion));*/
      yyminorunion = yyzerominor;
      yyStackOverflow(yypParser, &yyminorunion);
      return;
    }
#endif
    yypParser->yyidx = 0;
    yypParser->yyerrcnt = -1;
    yypParser->yystack[0].stateno = 0;
    yypParser->yystack[0].major = 0;
  }
  yyminorunion.yy0 = yyminor;
  yyendofinput = (yymajor==0);
  sqlite3ParserARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput %s\n",yyTracePrompt,yyTokenName[yymajor]);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact<YYNSTATE ){
      assert( !yyendofinput );  /* Impossible to shift the $ token */
      yy_shift(yypParser,yyact,yymajor,&yyminorunion);
      yypParser->yyerrcnt--;
      yymajor = YYNOCODE;
    }else if( yyact < YYNSTATE + YYNRULE ){
      yy_reduce(yypParser,yyact-YYNSTATE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion);
      }
      yymx = yypParser->yystack[yypParser->yyidx].major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor,&yyminorunion);
        yymajor = YYNOCODE;
      }else{
         while(
          yypParser->yyidx >= 0 &&
          yymx != YYERRORSYMBOL &&
          (yyact = yy_find_reduce_action(
                        yypParser->yystack[yypParser->yyidx].stateno,
                        YYERRORSYMBOL)) >= YYNSTATE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yyidx < 0 || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          YYMINORTYPE u2;
          u2.YYERRSYMDT = 0;
          yy_shift(yypParser,yyact,YYERRORSYMBOL,&u2);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yyidx>=0 );
  return;
}
